@@ -3,47 +3,12 @@ package ICC::Profile;
 use strict;
 use Carp;
 
-our $VERSION = 0.61;
+our $VERSION = 0.7;
 
-# revised 2018-03-29
+# revised 2018-09-09
 #
 # Copyright © 2004-2018 by William B. Birkett
 
-# add development directories
-BEGIN {
-
-	# local variable
-	my ($home);
-
-	# if Windows
-	if ($^O eq 'MSWin32') {
-		
-		# use Parallels home volume
-		$home = 'Y:';
-		
-	} else {
-		
-		# use UNIX home path
-		$home = $ENV{'HOME'};
-		
-	}
-
-	# if my ICC::Profile development directory exists
-	if (-d "$home/Projects/Software/ICC_Modules/ICC-Profile/lib") {
-		
-		# add all development directories to @INC
-		unshift(@INC, "$home/Projects/Software/ICC_Modules/ICC-Profile/lib");
-		unshift(@INC, "$home/Projects/Software/ICC_Modules/ICC-Support-Image/lib");
-		unshift(@INC, "$home/Projects/Software/ICC_Modules/ICC-Support-Image/blib/arch");
-		unshift(@INC, "$home/Projects/Software/ICC_Modules/ICC-Support-Lapack/blib/lib");
-		unshift(@INC, "$home/Projects/Software/ICC_Modules/ICC-Support-Lapack/blib/arch");
-		unshift(@INC, "$home/Projects/Software/ICC_Modules/ICC-Support-Levmar/blib/lib");
-		unshift(@INC, "$home/Projects/Software/ICC_Modules/ICC-Support-Levmar/blib/arch");
-		
-	}
-
-}
-
 # global variables
 our (@EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 
@@ -60,7 +25,6 @@ BEGIN {
 	@modules = qw(
 		Data::Dumper
 		Digest::MD5
-		File::Glob
 		ICC::Profile::clro
 		ICC::Profile::clrt
 		ICC::Profile::clut
@@ -91,7 +55,6 @@ BEGIN {
 		ICC::Profile::XYZ_
 		ICC::Profile::ZXML
 		ICC::Shared
-		ICC::Support::akima
 		ICC::Support::bern
 		ICC::Support::Chart
 		ICC::Support::Color
@@ -105,7 +68,6 @@ BEGIN {
 		ICC::Support::ratfunc
 		ICC::Support::rbf
 		ICC::Support::spline
-		ICC::Support::spline2
 	);
 
 	# optional modules
@@ -197,7 +159,7 @@ sub new {
 	} elsif (@_) {
 		
 		# read data from existing profile
-		_readICCprofile($self, @_) || carp("couldn't read profile: $_[0]\n");
+		_readICCprofile($self, @_) or carp("couldn't read profile: $_[0]\n");
 		
 	}
 
@@ -332,7 +294,7 @@ sub tag {
 			$value = $hash->{$key};
 			
 			# verify tag signature
-			(length($key) == 4) || croak('tag signature wrong length');
+			(length($key) == 4) or croak('tag signature wrong length');
 			
 			# match tag signature
 			@match = grep {$key eq $self->[2][$_][0]} (0 .. $#{$self->[2]});
@@ -460,7 +422,7 @@ sub write {
 	my $self = shift();
 
 	# verify parameter count
-	(@_ == 1) || croak('wrong number of parameters');
+	(@_ == 1) or croak('wrong number of parameters');
 
 	# write profile
 	_writeICCprofile($self, @_);
@@ -667,7 +629,7 @@ sub _newICCprofile {
 	$version = defined($version) ? $version : '02400000';
 
 	# verify version number (section 7.2.4, ICC1v43_2010-12)
-	($version =~ m/^[0-9]{4}0000$/) || croak('invalid version number');
+	($version =~ m/^[0-9]{4}0000$/) or croak('invalid version number');
 
 	# get major revision
 	$vmaj = substr($version, 0, 2);
@@ -676,25 +638,25 @@ sub _newICCprofile {
 	$vmin = substr($version, 2, 1);
 
 	# verify profile class (required) (table 18, ICC1v43_2010-12)
-	(defined($class)) || croak('missing profile class parameter');
-	($class =~ m/^(scnr|mntr|prtr|link|spac|abst|nmcl)$/) || croak('invalid profile class');
+	(defined($class)) or croak('missing profile class parameter');
+	($class =~ m/^(scnr|mntr|prtr|link|spac|abst|nmcl)$/) or croak('invalid profile class');
 
 	# resolve subclass (optional, default 0)
 	$subclass = defined($subclass) ? $subclass : 0;
 
 	# verify data color space (required)
-	(defined($dcs)) || croak('missing data color space parameter');
-	(($dcs =~ $repcs) || ($class ne 'abst' && $dcs =~ $redcs)) || croak('invalid data color space');
+	(defined($dcs)) or croak('missing data color space parameter');
+	(($dcs =~ $repcs) || ($class ne 'abst' && $dcs =~ $redcs)) or croak('invalid data color space');
 
 	# verify profile connection space (required)
-	$pcs = $hash->{'PCS'} || croak('missing profile connection space parameter');
-	(($pcs =~ $repcs) || ($class eq 'link' && $pcs =~ $redcs)) || croak('invalid profile connection space');
+	$pcs = $hash->{'PCS'} or croak('missing profile connection space parameter');
+	(($pcs =~ $repcs) || ($class eq 'link' && $pcs =~ $redcs)) or croak('invalid profile connection space');
 
 	# resolve default rendering intent (optional, default 0)
 	$dri = defined($dri) ? $dri : 0;
 
 	# verify default rendering intent (table 23, ICC1v43_2010-12)
-	($dri =~ m/^[0-3]$/) || croak('invalid default rendering intent');
+	($dri =~ m/^[0-3]$/) or croak('invalid default rendering intent');
 
 	# set header (note: size, time and ID are computed when writing profile)
 	$self->[1] = [
@@ -1134,6 +1096,9 @@ sub _readICCprofile {
 	# if path a scalar
 	} elsif (! ref($path)) {
 		
+		# replace '~~' with 'ICC' directory path
+		$path =~ s/^~~(?{ICC::Shared::getICCPath})/$^R/;
+		
 		# filter file path
 		ICC::Shared::filterPath($path);
 		
@@ -1453,7 +1418,7 @@ sub _writeICCprofile {
 		$sig = $self->[2][$i][0];
 		
 		# error if duplicate tag
-		(! exists($dup{$sig})) || croak("duplicate '$sig' tag");
+		(! exists($dup{$sig})) or croak("duplicate '$sig' tag");
 		
 		# add tag to duplicate hash
 		$dup{$sig} = '';
