@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.22;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -63,7 +63,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read ZXML data from profile
 	_readICCZXML($self, @_);
@@ -80,14 +80,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write ZXML data to profile
-	_writeICCZXML($self, @_);
+	goto &_writeICCZXML;
 
 }
 
@@ -147,13 +144,13 @@ sub text {
 		($d, $status) = Compress::Raw::Zlib::Deflate->new('-AppendOutput' => 1);
 		
 		# check status
-		($status == Z_OK) || croak("zlib error $status creating deflation object");
+		($status == Z_OK) or croak("zlib error $status creating deflation object");
 		
 		# deflate the text string (adding 4 nulls)
 		$status = $d->deflate(pack('a* x4', $cxf), $self->[1]);
 		
 		# check status
-		($status == Z_OK) || croak("zlib error $status deflating text string");
+		($status == Z_OK) or croak("zlib error $status deflating text string");
 		
 		# finish decompression
 		$status = $d->flush($self->[1]);
@@ -164,13 +161,13 @@ sub text {
 		($i, $status) = Compress::Raw::Zlib::Inflate->new();
 		
 		# check status
-		($status == Z_OK) || croak("zlib error $status creating inflation object");
+		($status == Z_OK) or croak("zlib error $status creating inflation object");
 		
 		# inflate entire zip string
 		$status = $i->inflate($self->[1], $cxf);
 		
 		# check status
-		($status == Z_STREAM_END) || croak("zlib error $status inflating text string");
+		($status == Z_STREAM_END) or croak("zlib error $status inflating text string");
 		
 		# trim nulls from end of string
 		$cxf = unpack('Z*', $cxf);
