@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.12;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -60,7 +60,7 @@ sub new_fh {
 			];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read clro data from profile
 	_readICCclro($self, @_);
@@ -77,14 +77,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write clro data to profile
-	_writeICCclro($self, @_);
+	goto &_writeICCclro;
 
 }
 
@@ -118,7 +115,7 @@ sub sequence {
 		my $i = 0;
 
 		# verify sequence array
-		(@{$seq} == grep {$_ == $i++} sort {$a <=> $b} @{$seq}) || croak('bad sequence array');
+		(@{$seq} == grep {$_ == $i++} sort {$a <=> $b} @{$seq}) or croak('bad sequence array');
 
 		# save array
 		$self->[1] = $seq;
@@ -167,7 +164,7 @@ sub _newICCclro {
 	my $i = 0;
 
 	# verify sequence array
-	(@{$seq} == grep {$_ == $i++} sort {$a <=> $b} @{$seq}) || croak('bad sequence array');
+	(@{$seq} == grep {$_ == $i++} sort {$a <=> $b} @{$seq}) or croak('bad sequence array');
 
 	# copy array
 	$self->[1] = [@{$seq}];
