@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.21;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -224,9 +224,9 @@ sub clut {
 	$gsa = $self->[2];
 
 	# validate indices
-	(@_ == @{$gsa}) || croak('wrong number of clut indices');
-	(@_ == grep {! ref() && $_ == int($_)} @_) || croak('clut index not an integer');
-	(@_ == grep {$_[$_] >= 0 && $_[$_] < $gsa->[$_]} 0 .. $#_) || croak('clut index out of range');
+	(@_ == @{$gsa}) or croak('wrong number of clut indices');
+	(@_ == grep {! ref() && $_ == int($_)} @_) or croak('clut index not an integer');
+	(@_ == grep {$_[$_] >= 0 && $_[$_] < $gsa->[$_]} 0 .. $#_) or croak('clut index out of range');
 
 	# initialize clut pointer
 	$lx = $_[0];
@@ -276,7 +276,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read clut data from profile
 	_readICCclut($self, @_);
@@ -293,14 +293,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get object reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write clut data to profile
-	_writeICCclut($self, @_);
+	goto &_writeICCclut;
 
 }
 
@@ -448,7 +445,7 @@ sub build {
 	$self->[0]{'input_channels'} = $ci = @{$gsa};
 
 	# validate user-defined function
-	(ref($self->[3][0]) eq 'CODE') || croak('invalid user-defined function');
+	(ref($self->[3][0]) eq 'CODE') or croak('invalid user-defined function');
 
 	# test user-defined function
 	@out = &{$self->[3][0]}((0) x $ci);
@@ -457,10 +454,10 @@ sub build {
 	$self->[0]{'output_channels'} = $co = @out;
 
 	# validate parameters
-	(@{$gsa} == grep {! ref() && $_ == int($_)} @{$gsa}) || croak('grid size not an integer');
-	(0 == grep {$_ < 2} @{$gsa}) || croak('grid size less than 2');
-	($ci > 0 && $ci < 16) || croak('invalid number of input channels');
-	($co > 0 && $co < 16) || croak('invalid number of output channels');
+	(@{$gsa} == grep {! ref() && $_ == int($_)} @{$gsa}) or croak('grid size not an integer');
+	(0 == grep {$_ < 2} @{$gsa}) or croak('grid size less than 2');
+	($ci > 0 && $ci < 16) or croak('invalid number of input channels');
+	($co > 0 && $co < 16) or croak('invalid number of output channels');
 
 	# initialize clut entries
 	$size = 1;
@@ -572,7 +569,7 @@ sub inverse {
 	$i = $j = -1;
 
 	# build slice arrays while validating input and output arrays
-	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) || croak('wrong number of undefined values');
+	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) or croak('wrong number of undefined values');
 
 	# get init array
 	$init = $hash->{'init'};
@@ -1796,10 +1793,10 @@ sub _writeICCclut {
 	$co = @{$self->[1][0]};
 
 	# validate number input channels (1 to 15)
-	($ci > 0 && $ci < 16) || croak('unsupported number of input channels');
+	($ci > 0 && $ci < 16) or croak('unsupported number of input channels');
 
 	# validate number output channels (1 to 15)
-	($co > 0 && $co < 16) || croak('unsupported number of output channels');
+	($co > 0 && $co < 16) or croak('unsupported number of output channels');
 
 	# for each possible input channel
 	for my $i (0 .. 15) {
