@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.12;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -75,7 +75,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read curf data from profile
 	_readICCcurf($self, @_);
@@ -92,14 +92,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write curf data to profile
-	_writeICCcurf($self, @_);
+	goto &_writeICCcurf;
 
 }
 
@@ -236,7 +233,7 @@ sub segment {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# set array reference
 		$self->[1] = [@{shift()}];
@@ -260,7 +257,7 @@ sub breakpoint {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# set array reference
 		$self->[2] = [@{shift()}];
@@ -446,10 +443,10 @@ sub _writeICCcurf {
 	my ($self, $parent, $fh, $tag) = @_;
 
 	# verify segments
-	(@{$self->[1]} > 0) || carp('\'curf\' object must contain at least one segment');
+	(@{$self->[1]} > 0) or carp('\'curf\' object must contain at least one segment');
 
 	# verify breakpoints
-	(@{$self->[1]} == @{$self->[2]} + 1) || carp('\'curf\' object must contain a breakpoint between each segment');
+	(@{$self->[1]} == @{$self->[2]} + 1) or carp('\'curf\' object must contain a breakpoint between each segment');
 
 	# seek start of tag
 	seek($fh, $tag->[1], 0);
