@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 2.11;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -39,7 +39,7 @@ sub new {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# copy array
 		$self->[1] = [@{shift()}];
@@ -74,7 +74,7 @@ sub inv {
 	} elsif (@{$self->array()} == 1) {
 		
 		# verify gamma > 0
-		($self->array->[0] > 0) || croak('gamma must be > 0');
+		($self->array->[0] > 0) or croak('gamma must be > 0');
 		
 		# return inverse gamma curve
 		return(ICC::Profile::curv->new([65536/$self->array->[0]]));
@@ -109,7 +109,7 @@ sub array {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# set array reference
 		$self->[1] = shift();
@@ -304,7 +304,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read curv data from profile
 	_readICCcurv($self, @_);
@@ -321,14 +321,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write curv data to profile
-	_writeICCcurv($self, @_);
+	goto &_writeICCcurv;
 
 }
 
