@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.12;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -65,7 +65,7 @@ sub new_fh {
 			];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read data from profile
 	_readICCdata($self, @_);
@@ -82,14 +82,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write data to profile
-	_writeICCdata($self, @_);
+	goto &_writeICCdata;
 
 }
 
