@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.12;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -426,7 +426,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read gbd_ data from profile
 	_readICCgbd_($self, @_);
@@ -443,14 +443,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get object reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write gbd_ data to profile
-	_writeICCgbd_($self, @_);
+	goto &_writeICCgbd_;
 
 }
 
@@ -678,16 +675,16 @@ sub _new_from_hash {
 		}
 		
 		# verify number of faces
-		(@{$self->[1]} >= 4) || croak('number of faces < 4');
+		(@{$self->[1]} >= 4) or croak('number of faces < 4');
 		
 		# verify number of vertices per face
-		(@{$self->[1]} == 3) || croak('number of vertices per face <> 3');
+		(@{$self->[1]} == 3) or croak('number of vertices per face <> 3');
 		
 		# check gamut faces
 		($f, $v, $e) = _check_faces($self);
 		
 		# verify closed shape using Euler's formula
-		($f + $v - $e == 2) || carp('not a closed shape');
+		($f + $v - $e == 2) or carp('not a closed shape');
 		
 	}
 
@@ -717,10 +714,10 @@ sub _new_from_hash {
 		}
 		
 		# verify number of vertices
-		(@{$self->[2]} >= 4) || croak('number of vertices < 4');
+		(@{$self->[2]} >= 4) or croak('number of vertices < 4');
 		
 		# verify number of pcs channels
-		(@{$self->[2][0]} >= 3) || croak('number of pcs channels < 3');
+		(@{$self->[2][0]} >= 3) or croak('number of pcs channels < 3');
 		
 	}
 
@@ -750,21 +747,21 @@ sub _new_from_hash {
 		}
 		
 		# verify number of vertices
-		(@{$self->[3]} >= 4) || croak('number of vertices < 4');
+		(@{$self->[3]} >= 4) or croak('number of vertices < 4');
 		
 		# verify number of pcs channels
-		(@{$self->[3][0]} >= 1 && @{$self->[3][0]} <= 16) || croak('number of device channels < 1 or > 16');
+		(@{$self->[3][0]} >= 1 && @{$self->[3][0]} <= 16) or croak('number of device channels < 1 or > 16');
 		
 	}
 	
 	# verify pcs array size
-	(@{$self->[2]} == 0 || @{$self->[2]} == $v) || croak('pcs and face arrays have different number of vertices');
+	(@{$self->[2]} == 0 || @{$self->[2]} == $v) or croak('pcs and face arrays have different number of vertices');
 	
 	# if both pcs and device arrays were supplied
 	if (defined($hash->{'pcs'}) && defined($hash->{'device'})) {
 		
 		# verify pcs and device arrays have same number of vertices
-		(@{$self->[2]} == @{$self->[3]}) || croak('pcs and device arrays are different sizes');
+		(@{$self->[2]} == @{$self->[3]}) or croak('pcs and device arrays are different sizes');
 		
 	}
 	
@@ -867,10 +864,10 @@ sub _writeICCgbd_ {
 	$f = @{$self->[1]};
 
 	# validate number PCS channels (3 and up)
-	($p >= 3) || croak('unsupported number of input channels');
+	($p >= 3) or croak('unsupported number of input channels');
 
 	# validate number device channels (1 to 15)
-	($q > 0 && $q < 16) || croak('unsupported number of output channels');
+	($q > 0 && $q < 16) or croak('unsupported number of output channels');
 
 	# seek start of tag
 	seek($fh, $tag->[1], 0);
