@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 2.51;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -114,7 +114,7 @@ sub array {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# set array reference
 		$self->[1] = [@{shift()}];
@@ -377,7 +377,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read mBA_ data from profile
 	_readICCmBA_($self, @_);
@@ -394,14 +394,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write mBA_ data to profile
-	_writeICCmBA_($self, @_);
+	goto &_writeICCmBA_;
 
 }
 
@@ -588,7 +585,7 @@ sub inverse {
 	$i = $j = -1;
 
 	# build slice arrays while validating input and output arrays
-	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) || croak('wrong number of undefined values');
+	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) or croak('wrong number of undefined values');
 
 	# get init array
 	$init = $hash->{'init'};
@@ -1038,7 +1035,7 @@ sub _check {
 	@class = qw(ICC::Profile::cvst ICC::Profile::matf ICC::Profile::cvst ICC::Profile::clut ICC::Profile::cvst);
 
 	# verify number of processing elements
-	($#{$self->[1]} <= 4) || croak('\'mBA_\' object has too many processing elements');
+	($#{$self->[1]} <= 4) or croak('\'mBA_\' object has too many processing elements');
 
 	# for each processing element
 	for my $i (0 .. $#{$self->[1]}) {
@@ -1047,7 +1044,7 @@ sub _check {
 		if (defined($self->[1][$i])) {
 			
 			# verify element has correct class
-			(ref($self->[1][$i]) eq $class[$i]) || croak("'mBA_' processing element $i has wrong class");
+			(ref($self->[1][$i]) eq $class[$i]) or croak("'mBA_' processing element $i has wrong class");
 			
 			# if element has 'cin' method
 			if ($self->[1][$i]->can('cin')) {
@@ -1064,7 +1061,7 @@ sub _check {
 				if (defined($co)) {
 					
 					# verify input channels of this element match output channels of previous element
-					($self->[1][$i]->cin() == $co) || croak("'mBA_' processing element $i has wrong number of channels");
+					($self->[1][$i]->cin() == $co) or croak("'mBA_' processing element $i has wrong number of channels");
 					
 				}
 				
@@ -1083,7 +1080,7 @@ sub _check {
 	}
 
 	# verify B-curves are defined
-	(defined($self->[1][0])) || croak('B-curves are required');
+	(defined($self->[1][0])) or croak('B-curves are required');
 
 	# verify matrix and M-curves are both defined, or neither
 	(defined($self->[1][1]) xor defined($self->[1][2])) && croak('matrix and M-curves must both be defined, or neither');
@@ -1095,13 +1092,13 @@ sub _check {
 	if (defined($self->[1][1])) {
 		
 		# verify object has 3 output channels
-		($ci == 3) || croak("matrix processing element not permitted with $ci input channels");
+		($ci == 3) or croak("matrix processing element not permitted with $ci input channels");
 		
 		# verify matrix size (3x3)
-		($self->[1][1]->cin() == 3 && $self->[1][1]->cout() == 3) || croak('matrix processing element matrix wrong size');
+		($self->[1][1]->cin() == 3 && $self->[1][1]->cout() == 3) or croak('matrix processing element matrix wrong size');
 		
 		# verify offset size (undefined, 0 or 3)
-		(! defined($self->[1][1][2]) || @{$self->[1][1][2]} == 0 || @{$self->[1][1][2]} == 3) || croak('matrix processing element offset wrong size');
+		(! defined($self->[1][1][2]) || @{$self->[1][1][2]} == 0 || @{$self->[1][1][2]} == 3) or croak('matrix processing element offset wrong size');
 		
 	}
 
@@ -1122,7 +1119,7 @@ sub _newICCmatrix {
 	my (@XYZ, @TRC, $wtpt, $bkpt, $id, $mat);
 
 	# verify an RGB/XYZ display profile
-	(UNIVERSAL::isa($disp, 'ICC::Profile') && $disp->profile_header->[3] eq 'mntr' && $disp->profile_header->[4] eq 'RGB ' && $disp->profile_header->[5] eq 'XYZ ') || croak('not an RGB-XYZ display profile');
+	(UNIVERSAL::isa($disp, 'ICC::Profile') && $disp->profile_header->[3] eq 'mntr' && $disp->profile_header->[4] eq 'RGB ' && $disp->profile_header->[5] eq 'XYZ ') or croak('not an RGB-XYZ display profile');
 
 	# get primary tags
 	@XYZ = $disp->tag(qw(rXYZ gXYZ bXYZ));
@@ -1131,7 +1128,7 @@ sub _newICCmatrix {
 	@TRC = $disp->tag(qw(rTRC gTRC bTRC));
 
 	# verify a matrix profile
-	(@XYZ == 3 && @TRC == 3) || croak('not a matrix profile');
+	(@XYZ == 3 && @TRC == 3) or croak('not a matrix profile');
 
 	# set input colorspace
 	$self->[0]{'input_cs'} = 'XYZ ';
@@ -1247,10 +1244,10 @@ sub _readICCmBA_ {
 	($mft[0] eq 'mBA ') or croak('wrong tag type');
 
 	# verify number input channels (1 to 15)
-	($mft[1] > 0 && $mft[1] < 16) || croak('unsupported number of input channels');
+	($mft[1] > 0 && $mft[1] < 16) or croak('unsupported number of input channels');
 
 	# verify number output channels (1 to 15)
-	($mft[2] > 0 && $mft[2] < 16) || croak('unsupported number of output channels');
+	($mft[2] > 0 && $mft[2] < 16) or croak('unsupported number of output channels');
 
 	# if B-curves are defined
 	if ($mft[3]) {
@@ -1536,7 +1533,7 @@ sub _writeICCmBA_ {
 	if (defined($self->[1][1])) {
 		
 		# verify output channels
-		($mft[2] == 3) || croak('3 output channels required for matrix');
+		($mft[2] == 3) or croak('3 output channels required for matrix');
 		
 		# set offset
 		$mft[4] = $offset;
@@ -1555,7 +1552,7 @@ sub _writeICCmBA_ {
 	if (defined($self->[1][2])) {
 		
 		# verify output channels
-		($mft[2] == 3) || croak('3 output channels required for M-curves');
+		($mft[2] == 3) or croak('3 output channels required for M-curves');
 		
 		# set offset
 		$mft[5] = $offset;
