@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.33;
 
-# revised 2016-12-03
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -249,6 +249,7 @@ sub quasi {
 }
 
 # create inverse 'matf' object
+# requires the matrix element to be square
 # returns: (ref_to_object)
 sub inv {
 
@@ -265,7 +266,7 @@ sub inv {
 	if (defined($self->[1][0][0])) {
 		
 		# verify matrix is square
-		(@{$self->[1]} == @{$self->[1][0]}) || croak('matrix must be square');
+		(@{$self->[1]} == @{$self->[1][0]}) or croak('matrix must be square');
 		
 		# invert matrix
 		$inv->[1] = $self->[1]->invert();
@@ -461,19 +462,19 @@ sub fit {
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
 
 	# verify ICC::Support::Lapack module is loaded
-	($lapack) || croak('\'fit\' method requires ICC::Support::Lapack module');
+	($lapack) or croak('\'fit\' method requires ICC::Support::Lapack module');
 
 	# resolve offset flag
 	$oflag = 0 if (! defined($oflag));
 
 	# verify input array
-	(ref($in) eq 'ARRAY' && ref($in->[0]) eq 'ARRAY' && ! ref($in->[0][0])) || UNIVERSAL::isa($in, 'Math::Matrix') || croak('fit input not a 2-D array reference');
+	(ref($in) eq 'ARRAY' && ref($in->[0]) eq 'ARRAY' && ! ref($in->[0][0])) || UNIVERSAL::isa($in, 'Math::Matrix') or croak('fit input not a 2-D array reference');
 
 	# verify output array
-	(ref($out) eq 'ARRAY' && ref($out->[0]) eq 'ARRAY' && ! ref($out->[0][0])) || UNIVERSAL::isa($out, 'Math::Matrix') || croak('fit output not a 2-D array reference');
+	(ref($out) eq 'ARRAY' && ref($out->[0]) eq 'ARRAY' && ! ref($out->[0][0])) || UNIVERSAL::isa($out, 'Math::Matrix') or croak('fit output not a 2-D array reference');
 
 	# verify array dimensions
-	($#{$in} == $#{$out}) || croak('\'fit\' input and output arrays have different number of rows');
+	($#{$in} == $#{$out}) or croak('\'fit\' input and output arrays have different number of rows');
 
 	# fit the matrix
 	($info, $ab) = ICC::Support::Lapack::matf_fit($in, $out, $oflag);
@@ -592,7 +593,7 @@ sub inverse {
 	$i = $j = -1;
 
 	# build slice arrays while validating input and output arrays
-	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) || croak('wrong number of undefined values');
+	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) or croak('wrong number of undefined values');
 
 	# for each undefined output value
 	for my $i (@so) {
@@ -780,7 +781,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read matf data from profile
 	_readICCmatf($self, @_);
@@ -797,14 +798,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get object reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write matf data to profile
-	_writeICCmatf($self, @_);
+	goto &_writeICCmatf;
 
 }
 
@@ -978,7 +976,7 @@ sub _trans0 {
 	$hash = pop() if (ref($_[-1]) eq 'HASH');
 
 	# validate number of input channels
-	(@_ == @{$self->[1][0]}) || croak('wrong number input channels');
+	(@_ == @{$self->[1][0]}) or croak('wrong number input channels');
 
 	# set output to offset values or zeros
 	@out = defined($self->[2][0]) ? @{$self->[2]} : (0) x @{$self->[1]};
@@ -1008,7 +1006,7 @@ sub _trans1 {
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
 
 	# validate number of input channels
-	(@{$in} == @{$self->[1][0]}) || croak('wrong number input channels');
+	(@{$in} == @{$self->[1][0]}) or croak('wrong number input channels');
 
 	# if ICC::Support::Lapack module is loaded
 	if ($lapack) {
@@ -1040,7 +1038,7 @@ sub _trans2 {
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
 
 	# validate number of input channels
-	(@{$in->[0]} == @{$self->[1][0]}) || croak('wrong number input channels');
+	(@{$in->[0]} == @{$self->[1][0]}) or croak('wrong number input channels');
 
 	# if ICC::Support::Lapack module is loaded
 	if ($lapack) {
@@ -1107,7 +1105,7 @@ sub _invsqr0 {
 	$hash = pop() if (ref($_[-1]) eq 'HASH');
 
 	# validate number of input channels
-	(@_ == @{$self->[1][0]}) || croak('wrong number input channels');
+	(@_ == @{$self->[1][0]}) or croak('wrong number input channels');
 
 	# return simple array
 	return(@{_invsqr1($self, [@_])});
@@ -1123,7 +1121,7 @@ sub _invsqr1 {
 	my ($self, $in, $hash) = @_;
 
 	# validate number of input channels
-	(@{$in} == @{$self->[1]}) || croak('wrong number input channels');
+	(@{$in} == @{$self->[1]}) or croak('wrong number input channels');
 
 	# clone the 'matf' matrix
 	my $sys = Storable::dclone($self->[1]);
@@ -1156,7 +1154,7 @@ sub _invsqr2 {
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
 
 	# validate number of input channels
-	(@{$in->[0]} == @{$self->[1]}) || croak('wrong number input channels');
+	(@{$in->[0]} == @{$self->[1]}) or croak('wrong number input channels');
 
 	# if ICC::Support::Lapack module is loaded
 	if ($lapack) {
@@ -1504,10 +1502,10 @@ sub _writeICCmatf {
 	$co = @{$self->[1]};
 	
 	# validate number input channels (1 to 15)
-	($ci > 0 && $ci < 16) || croak('unsupported number of input channels');
+	($ci > 0 && $ci < 16) or croak('unsupported number of input channels');
 
 	# validate number output channels (1 to 15)
-	($co > 0 && $co < 16) || croak('unsupported number of output channels');
+	($co > 0 && $co < 16) or croak('unsupported number of output channels');
 
 	# seek start of tag
 	seek($fh, $tag->[1], 0);
