@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 2.51;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -106,7 +106,7 @@ sub array {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# set array reference
 		$self->[1] = [@{shift()}];
@@ -133,7 +133,7 @@ sub matrix {
 		if (@_ == 1 && UNIVERSAL::isa($_[0], 'ICC::Profile::matf')) {
 			
 			# warn if 'matf' object has offset values
-			(@{$_[0]->offset()}) || carp('offset values in matrix object are not supported');
+			(@{$_[0]->offset()}) or carp('offset values in matrix object are not supported');
 			
 			# set matrix to new object
 			$self->[1][0] = shift();
@@ -338,7 +338,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read mft2 data from profile
 	_readICCmft2($self, @_);
@@ -355,14 +355,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write mft2 data to profile
-	_writeICCmft2($self, @_);
+	goto &_writeICCmft2;
 
 }
 
@@ -493,7 +490,7 @@ sub inverse {
 	$i = $j = -1;
 
 	# build slice arrays while validating input and output arrays
-	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) || croak('wrong number of undefined values');
+	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) or croak('wrong number of undefined values');
 
 	# get init array
 	$init = $hash->{'init'};
@@ -959,7 +956,7 @@ sub _check {
 	@class = qw(ICC::Profile::matf ICC::Profile::cvst ICC::Profile::clut ICC::Profile::cvst);
 
 	# verify number of processing elements
-	($#{$self->[1]} == 3) || croak('\'mft2\' object has wrong number of processing elements');
+	($#{$self->[1]} == 3) or croak('\'mft2\' object has wrong number of processing elements');
 
 	# for each processing element
 	for my $i (0 .. 3) {
@@ -968,7 +965,7 @@ sub _check {
 		if (defined($self->[1][$i])) {
 			
 			# verify element has correct class
-			(ref($self->[1][$i]) eq $class[$i]) || croak("'mft2' processing element $i is wrong object type");
+			(ref($self->[1][$i]) eq $class[$i]) or croak("'mft2' processing element $i is wrong object type");
 			
 			# if not matrix processing element
 			if ($i) {
@@ -985,7 +982,7 @@ sub _check {
 				if (defined($co)) {
 					
 					# verify input channels of this element match output channels of previous element
-					($self->[1][$i]->cin() == $co) || croak("'mft2' processing element $i has wrong number of input channels");
+					($self->[1][$i]->cin() == $co) or croak("'mft2' processing element $i has wrong number of input channels");
 					
 				}
 				
@@ -995,7 +992,7 @@ sub _check {
 			} else {
 				
 				# verify matrix has 3 input and 3 output channels
-				($self->[1][0]->cin() == 3 && $self->[1][0]->cout() == 3) || croak("'mft2' matrix processing element wrong size");
+				($self->[1][0]->cin() == 3 && $self->[1][0]->cout() == 3) or croak("'mft2' matrix processing element wrong size");
 				
 				# warn if matrix has non-zero offset values
 				(defined($self->[1][0]->offset) && grep {$_} @{$self->[1][0]->offset}) && carp("'mft2' matrix processing element has non-zero offset values")
@@ -1016,31 +1013,31 @@ sub _check {
 	$gsa = $self->[1][2]->gsa();
 
 	# verify 'clut' grid points are same for each channel
-	(@{$gsa} == grep {$_ == $gsa->[0]} @{$gsa}) || croak("'mft2' clut processing element grid points vary by channel");
+	(@{$gsa} == grep {$_ == $gsa->[0]} @{$gsa}) or croak("'mft2' clut processing element grid points vary by channel");
 
 	# verify input 'cvst' elements are 'curv' objects
-	(@{$self->[1][1]->array} == map {UNIVERSAL::isa($_, 'ICC::Profile::curv')} @{$self->[1][1]->array}) || croak("'mft2' input processing element has wrong curve type");
+	(@{$self->[1][1]->array} == map {UNIVERSAL::isa($_, 'ICC::Profile::curv')} @{$self->[1][1]->array}) or croak("'mft2' input processing element has wrong curve type");
 
 	# get number of entries from first input 'curv' object
 	$n = @{$self->[1][1]->array->[0]->array};
 
 	# verify number of entries is between 2 and 4096
-	($n >= 2 && $n <= 4096) || croak("'mft2' input processing element has wrong number of curve entries");
+	($n >= 2 && $n <= 4096) or croak("'mft2' input processing element has wrong number of curve entries");
 
 	# verify input 'curv' objects have same number of entries
-	(@{$self->[1][1]->array} == grep {@{$_->array} == $n} @{$self->[1][1]->array}) || croak("'mft2' input processing elements have different numbers of curve entries");
+	(@{$self->[1][1]->array} == grep {@{$_->array} == $n} @{$self->[1][1]->array}) or croak("'mft2' input processing elements have different numbers of curve entries");
 
 	# verify output 'cvst' elements are 'curv' objects
-	(@{$self->[1][3]->array} == map {UNIVERSAL::isa($_, 'ICC::Profile::curv')} @{$self->[1][3]->array}) || croak("'mft2' output processing element has wrong curve type");
+	(@{$self->[1][3]->array} == map {UNIVERSAL::isa($_, 'ICC::Profile::curv')} @{$self->[1][3]->array}) or croak("'mft2' output processing element has wrong curve type");
 
 	# get number of entries from first output 'curv' object
 	$n = @{$self->[1][3]->array->[0]->array};
 
 	# verify number of entries is between 2 and 4096
-	($n >= 2 && $n <= 4096) || croak("'mft2' output processing element has wrong number of curve entries");
+	($n >= 2 && $n <= 4096) or croak("'mft2' output processing element has wrong number of curve entries");
 
 	# verify output 'curv' objects have same number of entries
-	(@{$self->[1][3]->array} == grep {@{$_->array} == $n} @{$self->[1][3]->array}) || croak("'mft2' output processing elements have different numbers of curve entries");
+	(@{$self->[1][3]->array} == grep {@{$_->array} == $n} @{$self->[1][3]->array}) or croak("'mft2' output processing elements have different numbers of curve entries");
 
 	# return
 	return($ci, $co, $gsa->[0]);
@@ -1152,10 +1149,10 @@ sub _readICCmft2 {
 	($mft[0] eq 'mft2') or croak('wrong tag type');
 
 	# verify number input channels (1 to 15)
-	($mft[1] > 0 && $mft[1] < 16) || croak('unsupported number of input channels');
+	($mft[1] > 0 && $mft[1] < 16) or croak('unsupported number of input channels');
 
 	# verify number output channels (1 to 15)
-	($mft[2] > 0 && $mft[2] < 16) || croak('unsupported number of output channels');
+	($mft[2] > 0 && $mft[2] < 16) or croak('unsupported number of output channels');
 
 	# make 'matf' object for matrix
 	$self->[1][0] = ICC::Profile::matf->new();
