@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.12;
 
-# revised 2015-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -39,7 +39,7 @@ sub new {
 	if (@_ == 3) {
 		
 		# verify country and language codes
-		(length($_[0]) == 2 && length($_[1]) == 2) || croak('country or language code wrong length');
+		(length($_[0]) == 2 && length($_[1]) == 2) or croak('country or language code wrong length');
 		
 		# add name record
 		$self->[2][0] = [$_[0], $_[1], 0, 0, $_[2]];
@@ -70,7 +70,7 @@ sub new_fh {
 			];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read mluc data from profile
 	_readICCmluc($self, @_);
@@ -87,14 +87,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write mluc data to profile
-	_writeICCmluc($self, @_);
+	goto &_writeICCmluc;
 
 }
 
@@ -183,7 +180,7 @@ sub text {
 		} else {
 			
 			# verify country and language codes
-			(length($_[0]) == 2 && length($_[1]) == 2) || croak('country or language code wrong length');
+			(length($_[0]) == 2 && length($_[1]) == 2) or croak('country or language code wrong length');
 			
 			# add new name record
 			push(@{$self->[2]}, [$_[0], $_[1], 0, 0, $_[2]]);
