@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.51;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -104,13 +104,13 @@ sub array {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# for each processing element
 		for my $i (0 .. $#{$_[0]}) {
 			
 			# verify object has processing methods
-			($_[0][$i]->can('_transform') && $_[0][$i]->can('jacobian')) || croak('processing element lacks \'transform\' or \'jacobian\' method');
+			($_[0][$i]->can('_transform') && $_[0][$i]->can('jacobian')) or croak('processing element lacks \'transform\' or \'jacobian\' method');
 			
 			# add processing element
 			$self->[1][$i] = $_[0][$i];
@@ -172,7 +172,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read mpet data from profile
 	_readICCmpet($self, @_);
@@ -189,14 +189,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write mpet data to profile
-	_writeICCmpet($self, @_);
+	goto &_writeICCmpet;
 
 }
 
@@ -332,7 +329,7 @@ sub inverse {
 	$i = $j = -1;
 
 	# build slice arrays while validating input and output arrays
-	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) || croak('wrong number of undefined values');
+	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) or croak('wrong number of undefined values');
 
 	# get init array
 	$init = $hash->{'init'};
@@ -790,7 +787,7 @@ sub _check {
 			if (defined($co)) {
 				
 				# verify input channels of this element match output channels of previous element
-				($self->[1][$i]->cin() == $co) || croak('\'mpet\' processing element has wrong number of channels');
+				($self->[1][$i]->cin() == $co) or croak('\'mpet\' processing element has wrong number of channels');
 				
 			}
 			
@@ -824,9 +821,9 @@ sub _new_from_array {
 	for my $i (0 .. $#{$array}) {
 		
 		# verify object has required processing methods
-		($array->[$i]->can('_trans1')) || croak('processing element lacks \'_trans1\'method');
-		($array->[$i]->can('_trans2')) || croak('processing element lacks \'_trans2\'method');
-		($array->[$i]->can('jacobian')) || croak('processing element lacks\'jacobian\' method');
+		($array->[$i]->can('_trans1')) or croak('processing element lacks \'_trans1\'method');
+		($array->[$i]->can('_trans2')) or croak('processing element lacks \'_trans2\'method');
+		($array->[$i]->can('jacobian')) or croak('processing element lacks\'jacobian\' method');
 		
 		# add processing element
 		$self->[1][$i] = $array->[$i];
@@ -983,7 +980,7 @@ sub _writeICCmpet {
 	for my $i (0 .. $#{$self->[1]}) {
 		
 		# verify processing element allowed in 'mpet' tag
-		(ref($self->[1][$i]) =~ m/^ICC::Profile::(cvst|matf|clut|Generic)$/) || croak('processing element not allowed in \'mpet\' tag');
+		(ref($self->[1][$i]) =~ m/^ICC::Profile::(cvst|matf|clut|Generic)$/) or croak('processing element not allowed in \'mpet\' tag');
 		
 		# if tag not in hash
 		if (! exists($hash{$self->[1][$i]})) {
