@@ -3,9 +3,9 @@ package ICC::Profile::para;
 use strict;
 use Carp;
 
-our $VERSION = 0.41;
+our $VERSION = 0.42;
 
-# revised 2016-05-17
+# revised 2018-08-31
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -36,13 +36,13 @@ sub new {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# verify function type
-		($_[0][0] == int($_[0][0]) && defined($Np[$_[0][0]])) || croak('invalid function type');
+		($_[0][0] == int($_[0][0]) && defined($Np[$_[0][0]])) or croak('invalid function type');
 		
 		# verify number of parameters
-		($#{$_[0]} == $Np[$_[0][0]]) || croak('wrong number of parameters');
+		($#{$_[0]} == $Np[$_[0][0]]) or croak('wrong number of parameters');
 		
 		# copy array
 		$self->[1] = [@{shift()}];
@@ -68,9 +68,9 @@ sub inv {
 	my @p = @{$self->[1]};
 
 	# validate parameters
-	($p[1]) || croak('invalid gamma value');
-	($p[2]) || croak('invalid a value') if ($p[0] > 0);
-	($p[4]) || croak('invalid c value') if ($p[0] > 2);
+	($p[1]) or croak('invalid gamma value');
+	($p[2]) or croak('invalid a value') if ($p[0] > 0);
+	($p[4]) or croak('invalid c value') if ($p[0] > 2);
 
 	# if type 0
 	if ($p[0] == 0) {
@@ -129,16 +129,16 @@ sub array {
 		$array = shift();
 		
 		# verify array reference
-		(ref($array) eq 'ARRAY') || croak('not an array reference');
+		(ref($array) eq 'ARRAY') or croak('not an array reference');
 		
 		# get function type
 		$type = $array->[0];
 		
 		# verify function type (integer, 0 - 4)
-		($type == int($type) && $type >= 0 && $type <= 4) || croak('invalid function type');
+		($type == int($type) && $type >= 0 && $type <= 4) or croak('invalid function type');
 		
 		# verify number of parameters
-		($#{$array} == $Np[$type]) || croak('wrong number of parameters');
+		($#{$array} == $Np[$type]) or croak('wrong number of parameters');
 		
 		# set array reference
 		$self->[1] = $array;
@@ -501,6 +501,140 @@ sub derivative {
 	
 }
 
+# directional parametric partial derivatives
+# nominal domain (0 - 1)
+# parameters: (input_value)
+# returns: (partial_derivative_array)
+sub parametric {
+
+	# get parameters
+	my ($self, $in) = @_;
+
+	# local variables
+	my ($array, $type);
+	my ($axb, $dyda, $dydb);
+
+	# get parameter array reference
+	$array = $self->[1];
+
+	# get function type
+	$type = $array->[0];
+
+	# function type 0
+	if ($type == 0) {
+		
+		# return ∂Y/∂γ
+		return($in**$array->[1] * log($in));
+		
+	# function type 1
+	} elsif ($type == 1) {
+		
+		# compute (aX + b) value
+		$axb = $array->[2] * $in + $array->[3];
+		
+		# if X >= -b/a
+		if ($axb >= 0) {
+			
+			# compute ∂Y/∂b
+			$dydb = $array->[1] * $axb**($array->[1] - 1);
+			
+			# compute ∂Y/∂a
+			$dyda = $dydb * $in;
+			
+			# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b
+			return($axb**$array->[1] * log($axb), $dyda, $dydb);
+			
+		} else {
+			
+			# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b
+			return(0, 0, 0);
+			
+		}
+		
+	# function type 2
+	} elsif ($type == 2) {
+		
+		# compute (aX + b) value
+		$axb = $array->[2] * $in + $array->[3];
+		
+		# if X >= -b/a
+		if ($axb >= 0) {
+			
+			# compute ∂Y/∂b
+			$dydb = $array->[1] * $axb**($array->[1] - 1);
+			
+			# compute ∂Y/∂a
+			$dyda = $dydb * $in;
+			
+			# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c
+			return($axb**$array->[1] * log($axb), $dyda, $dydb, 1);
+			
+		} else {
+			
+			# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c
+			return(0, 0, 0, 1);
+			
+		}
+		
+	# function type 3
+	} elsif ($type == 3) {
+		
+		# if X >= d
+		if ($in >= $array->[5]) {
+			
+			# compute (aX + b) value
+			$axb = $array->[2] * $in + $array->[3];
+			
+			# compute ∂Y/∂b
+			$dydb = $array->[1] * $axb**($array->[1] - 1);
+			
+			# compute ∂Y/∂a
+			$dyda = $dydb * $in;
+			
+			# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c
+			return($axb**$array->[1] * log($axb), $dyda, $dydb, 0);
+			
+		} else {
+			
+			# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c
+			return(0, 0, 0, $in);
+			
+		}
+		
+	# function type 4
+	} elsif ($type == 4) {
+		
+		# if X >= d
+		if ($in >= $array->[5]) {
+			
+			# compute (aX + b) value
+			$axb = $array->[2] * $in + $array->[3];
+			
+			# compute ∂Y/∂b
+			$dydb = $array->[1] * $axb**($array->[1] - 1);
+			
+			# compute ∂Y/∂a
+			$dyda = $dydb * $in;
+			
+			# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c, ∂Y/∂e, ∂Y/∂f
+			return($axb**$array->[1] * log($axb), $dyda, $dydb, 0, 1, 0);
+			
+		} else {
+			
+			# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c, ∂Y/∂e, ∂Y/∂f
+			return(0, 0, 0, $in, 0, 1);
+			
+		}
+		
+	} else {
+		
+		# error
+		croak('invalid parametric function type');
+		
+	}
+	
+}
+
 # create para tag object from ICC profile
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 # returns: (ref_to_object)
@@ -516,7 +650,7 @@ sub new_fh {
 			];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read para data from profile
 	_readICCpara($self, @_);
@@ -533,14 +667,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write para data to profile
-	_writeICCpara($self, @_);
+	goto &_writeICCpara;
 
 }
 
@@ -569,7 +700,7 @@ sub table {
 	my ($up, $table);
 
 	# validate number of table entries
-	($n == int($n) && $n >= 2) || carp('invalid number of table entries');
+	($n == int($n) && $n >= 2) or carp('invalid number of table entries');
 
 	# array upper index
 	$up = $n - 1;
@@ -671,191 +802,6 @@ sub sdump {
 
 }
 
-# directional parametric partial derivatives
-# nominal domain (0 - 1)
-# direction: 0 - normal, 1 - inverse
-# parameters: (object_reference, direction, input_value)
-# returns: (partial_derivative_array)
-sub _parametric {
-	
-	# get parameters
-	my ($self, $dir, $in) = @_;
-	
-	# local variables
-	my ($array, $type);
-	my ($axb, $dyda, $dydb);
-	
-	# get parameter array reference
-	$array = $self->[1];
-	
-	# get function type
-	$type = $array->[0];
-	
-	# function type 0
-	if ($type == 0) {
-		
-		# if inverse
-		if ($dir) {
-			
-			# return ∂X/∂γ
-			return();
-			
-		} else {
-			
-			# return ∂Y/∂γ
-			return($in**$array->[1] * log($in));
-			
-		}
-		
-	# function type 1
-	} elsif ($type == 1) {
-		
-		# if inverse
-		if ($dir) {
-			
-			# return ∂X/∂γ, ∂X/∂a, ∂X/∂b
-			return();
-			
-		} else {
-			
-			# compute (aX + b) value
-			$axb = $array->[2] * $in + $array->[3];
-			
-			# if X >= -b/a
-			if ($axb >= 0) {
-				
-				# compute ∂Y/∂b
-				$dydb = $array->[1] * $axb**($array->[1] - 1);
-				
-				# compute ∂Y/∂a
-				$dyda = $dydb * $in;
-				
-				# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b
-				return($axb**$array->[1] * log($axb), $dyda, $dydb);
-				
-			} else {
-				
-				# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b
-				return(0, 0, 0);
-				
-			}
-			
-		}
-		
-	# function type 2
-	} elsif ($type == 2) {
-		
-		# if inverse
-		if ($dir) {
-			
-			# return ∂X/∂γ, ∂X/∂a, ∂X/∂b, ∂X/∂c
-			return();
-			
-		} else {
-			
-			# compute (aX + b) value
-			$axb = $array->[2] * $in + $array->[3];
-			
-			# if X >= -b/a
-			if ($axb >= 0) {
-				
-				# compute ∂Y/∂b
-				$dydb = $array->[1] * $axb**($array->[1] - 1);
-				
-				# compute ∂Y/∂a
-				$dyda = $dydb * $in;
-				
-				# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c
-				return($axb**$array->[1] * log($axb), $dyda, $dydb, 1);
-				
-			} else {
-				
-				# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c
-				return(0, 0, 0, 1);
-				
-			}
-			
-		}
-		
-	# function type 3
-	} elsif ($type == 3) {
-		
-		# if inverse
-		if ($dir) {
-			
-			# return ∂X/∂γ, ∂X/∂a, ∂X/∂b, ∂X/∂c
-			return();
-			
-		} else {
-			
-			# if X >= d
-			if ($in >= $array->[5]) {
-				
-				# compute (aX + b) value
-				$axb = $array->[2] * $in + $array->[3];
-				
-				# compute ∂Y/∂b
-				$dydb = $array->[1] * $axb**($array->[1] - 1);
-				
-				# compute ∂Y/∂a
-				$dyda = $dydb * $in;
-				
-				# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c
-				return($axb**$array->[1] * log($axb), $dyda, $dydb, 0);
-				
-			} else {
-				
-				# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c
-				return(0, 0, 0, $in);
-				
-			}
-			
-		}
-		
-	# function type 4
-	} elsif ($type == 4) {
-		
-		# if inverse
-		if ($dir) {
-			
-			# return ∂X/∂γ, ∂X/∂a, ∂X/∂b, ∂X/∂c, ∂X/∂e, ∂X/∂f
-			return();
-			
-		} else {
-			
-			# if X >= d
-			if ($in >= $array->[5]) {
-				
-				# compute (aX + b) value
-				$axb = $array->[2] * $in + $array->[3];
-				
-				# compute ∂Y/∂b
-				$dydb = $array->[1] * $axb**($array->[1] - 1);
-				
-				# compute ∂Y/∂a
-				$dyda = $dydb * $in;
-				
-				# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c, ∂Y/∂e, ∂Y/∂f
-				return($axb**$array->[1] * log($axb), $dyda, $dydb, 0, 1, 0);
-				
-			} else {
-				
-				# return ∂Y/∂γ, ∂Y/∂a, ∂Y/∂b, ∂Y/∂c, ∂Y/∂e, ∂Y/∂f
-				return(0, 0, 0, $in, 0, 1);
-				
-			}
-			
-		}
-		
-	} else {
-		
-		# error
-		croak('invalid parametric function type');
-		
-	}
-	
-}
-
 # directional derivative
 # nominal domain (0 - 1)
 # direction: 0 - normal, 1 - inverse
@@ -942,7 +888,7 @@ sub _readICCpara {
 	$fun = unpack('x8 n x2', $buf);
 
 	# get parameter count and verify
-	defined($cnt = $Np[$fun]) || croak('invalid function type when reading \'para\' tag');
+	defined($cnt = $Np[$fun]) or croak('invalid function type when reading \'para\' tag');
 
 	# read parameter values
 	read($fh, $buf, $cnt * 4);
@@ -960,7 +906,7 @@ sub _writeICCpara {
 	my ($self, $parent, $fh, $tag) = @_;
 
 	# verify object structure
-	($self->[1][0] == int($self->[1][0]) && defined($Np[$self->[1][0]]) && $Np[$self->[1][0]] == $#{$self->[1]}) || croak('invalid function data when writing \'para\' tag');
+	($self->[1][0] == int($self->[1][0]) && defined($Np[$self->[1][0]]) && $Np[$self->[1][0]] == $#{$self->[1]}) or croak('invalid function data when writing \'para\' tag');
 
 	# seek start of tag
 	seek($fh, $tag->[1], 0);
