@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.2;
 
-# revised 2016-10-22
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -36,13 +36,13 @@ sub new {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# verify function type
-		($_[0][0] == int($_[0][0]) && defined($Np[$_[0][0]])) || croak('invalid function type');
+		($_[0][0] == int($_[0][0]) && defined($Np[$_[0][0]])) or croak('invalid function type');
 		
 		# verify number of parameters
-		($#{$_[0]} == $Np[$_[0][0]]) || croak('wrong number of parameters');
+		($#{$_[0]} == $Np[$_[0][0]]) or croak('wrong number of parameters');
 		
 		# copy array
 		$self->[1] = [@{shift()}];
@@ -72,7 +72,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read parf data from profile
 	_readICCparf($self, @_);
@@ -89,14 +89,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write parf data to profile
-	_writeICCparf($self, @_);
+	goto &_writeICCparf;
 
 }
 
@@ -331,16 +328,16 @@ sub array {
 		$array = shift();
 		
 		# verify array reference
-		(ref($array) eq 'ARRAY') || croak('not an array reference');
+		(ref($array) eq 'ARRAY') or croak('not an array reference');
 		
 		# get function type
 		$type = $array->[0];
 		
 		# verify function type (integer, 0 - 5)
-		($type == int($type) && $type >= 0 && $type <= 5) || croak('invalid function type');
+		($type == int($type) && $type >= 0 && $type <= 5) or croak('invalid function type');
 		
 		# verify number of parameters
-		($#{$array} == $Np[$type]) || croak('wrong number of parameters');
+		($#{$array} == $Np[$type]) or croak('wrong number of parameters');
 		
 		# set array reference
 		$self->[1] = $array;
@@ -442,7 +439,7 @@ sub _readICCparf {
 	$fun = unpack('x8 n x2', $buf);
 
 	# get parameter count and verify
-	defined($cnt = $Np[$fun]) || croak('invalid function type when reading \'parf\' tag');
+	defined($cnt = $Np[$fun]) or croak('invalid function type when reading \'parf\' tag');
 
 	# read parameter values
 	read($fh, $buf, $cnt * 4);
@@ -460,7 +457,7 @@ sub _writeICCparf {
 	my ($self, $parent, $fh, $tag) = @_;
 
 	# verify object structure
-	($self->[1][0] == int($self->[1][0]) && $self->[1][0] >= 0 && $self->[1][0] <= 2 && $Np[$self->[1][0]] == $#{$self->[1]}) || croak('invalid function data when writing \'parf\' tag');
+	($self->[1][0] == int($self->[1][0]) && $self->[1][0] >= 0 && $self->[1][0] <= 2 && $Np[$self->[1][0]] == $#{$self->[1]}) or croak('invalid function data when writing \'parf\' tag');
 
 	# seek start of tag
 	seek($fh, $tag->[1], 0);
