@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.22;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -60,7 +60,7 @@ sub new_fh {
 			];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read pseq data from profile
 	_readICCpseq($self, @_);
@@ -77,14 +77,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write pseq data to profile
-	_writeICCpseq($self, @_);
+	goto &_writeICCpseq;
 
 }
 
@@ -188,7 +185,7 @@ sub _newICCpseq {
 	my ($vmaj, @pds);
 	
 	# verify array of profile objects
-	(! grep {ref() ne 'ICC::Profile'} @_) || croak('not a profile object');
+	(! grep {ref() ne 'ICC::Profile'} @_) or croak('not a profile object');
 	
 	# for each profile
 	for my $profile (@_) {
@@ -292,7 +289,7 @@ sub _readICCpseq {
 			read($fh, $buf, 100);
 			
 			# match allowed tag type signatures
-			($buf =~ m/(desc|mluc|\x3f\x00)/g) || croak('invalid profile description structure');
+			($buf =~ m/(desc|mluc|\x3f\x00)/g) or croak('invalid profile description structure');
 			
 			# seek start of next profile description structure
 			seek($fh, $eot + pos($buf) - 20 - length($1), 0);
@@ -368,7 +365,7 @@ sub _readICCpseq {
 		read($fh, $buf, 100);
 		
 		# match allowed tag type signatures
-		($buf =~ m/(desc|mluc|\x3f\x00)/g) || croak('invalid profile description structure');
+		($buf =~ m/(desc|mluc|\x3f\x00)/g) or croak('invalid profile description structure');
 		
 		# mark start of next tag
 		$mark = $eot + pos($buf) - length($1);
