@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.22;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -85,7 +85,7 @@ sub new_fh {
 			];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read sf32 data from profile
 	_readICCsf32($self, @_);
@@ -102,14 +102,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write sf32 data to profile
-	_writeICCsf32($self, @_);
+	goto &_writeICCsf32;
 
 }
 
@@ -137,7 +134,7 @@ sub array {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# set array reference
 		$self->[1] = shift();
@@ -176,7 +173,7 @@ sub matrix {
 			$cols = shift();
 			
 			# verify matrix dimensions
-			($size && $cols && ($size % $cols == 0)) || croak('invalid matrix dimensions');
+			($size && $cols && ($size % $cols == 0)) or croak('invalid matrix dimensions');
 			
 			# make new empty matrix object
 			$matrix = Math::Matrix->new([]);
