@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.12;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -38,7 +38,7 @@ sub new {
 		if (@_ == 1 && ref($_[0]) eq 'ARRAY' && @{$_[0]} == grep {UNIVERSAL::isa($_, 'ICC::Profile::curv')} @{$_[0]}) {
 			
 			# verify one or three objects
-			(@{$_[0]} == 1 || @{$_[0]} == 3) || croak('array must contain one or three \'curv\' objects');
+			(@{$_[0]} == 1 || @{$_[0]} == 3) or croak('array must contain one or three \'curv\' objects');
 			
 			# copy array
 			$self->[1] = [@{shift()}];
@@ -47,7 +47,7 @@ sub new {
 		} elsif (@_ == 1 && (ref($_[0]) eq 'ARRAY') && @{$_[0]} == grep {ref() eq 'ARRAY'} @{$_[0]}) {
 			
 			# verify 3x3 scalar array
-			(3 == @{$_[0]} && 3 == @{$_[0][0]} && 3 == grep {! ref()} @{$_[0][0]}) || croak('array must contain 3x3 scalar array');
+			(3 == @{$_[0]} && 3 == @{$_[0][0]} && 3 == grep {! ref()} @{$_[0][0]}) or croak('array must contain 3x3 scalar array');
 			
 			# copy array
 			$self->[1] = Storable::dclone(shift());
@@ -83,7 +83,7 @@ sub new_fh {
 	];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read vcgt data from profile
 	_readICCvcgt($self, @_);
@@ -100,14 +100,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write vcgt data to profile
-	_writeICCvcgt($self, @_);
+	goto &_writeICCvcgt;
 
 }
 
@@ -158,7 +155,7 @@ sub array {
 	if (@_) {
 		
 		# verify array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# set array reference
 		$self->[1] = shift();
@@ -343,10 +340,10 @@ sub _transform {
 	my (@out);
 
 	# verify inputs are all scalars
-	(@in == grep {! ref()} @in) || croak('invalid transform input');
+	(@in == grep {! ref()} @in) or croak('invalid transform input');
 
 	# verify number of inputs equals number of channels
-	(@in == @{$self->[1]}) || croak('wrong number of input values');
+	(@in == @{$self->[1]}) or croak('wrong number of input values');
 
 	# for each channel
 	for my $i (0 .. $#{$self->[1]}) {
