@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.12;
 
-# revised 2016-05-17
+# revised 2018-08-07
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -65,7 +65,7 @@ sub new_fh {
 			];
 
 	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	(@_ == 3) or croak('wrong number of parameters');
 
 	# read view data from profile
 	_readICCview($self, @_);
@@ -82,14 +82,11 @@ sub new_fh {
 # parameters: (ref_to_parent_object, file_handle, ref_to_tag_table_entry)
 sub write_fh {
 
-	# get tag reference
-	my $self = shift();
-
-	# verify 3 parameters
-	(@_ == 3) || croak('wrong number of parameters');
+	# verify 4 parameters
+	(@_ == 4) or croak('wrong number of parameters');
 
 	# write view data to profile
-	_writeICCview($self, @_);
+	goto &_writeICCview;
 
 }
 
@@ -117,7 +114,7 @@ sub XYZ {
 	my $i = shift();
 	
 	# verify index
-	($i == 0 || $i == 1) || croak('invalid view index');
+	($i == 0 || $i == 1) or croak('invalid view index');
 
 	# return XYZ values
 	return($self->[$i + 1]);
@@ -140,7 +137,7 @@ sub type {
 		my $type = shift();
 		
 		# verify type value
-		($type == int($type) && $type >= 0 && $type <= 8) || croak('invalid illuminant type');
+		($type == int($type) && $type >= 0 && $type <= 8) or croak('invalid illuminant type');
 		
 		# save it
 		$self->[3] = $type;
