@@ -2,6 +2,7 @@ package ICC::Shared;
 
 use strict;
 use Carp;
+use File::Path;
 use File::Spec;
 use List::Util;
 use Math::Matrix;
@@ -11,9 +12,9 @@ use Storable;
 use YAML::Tiny;
 use Exporter qw(import);
 
-our $VERSION = 0.53;
+our $VERSION = 0.57;
 
-# revised 2018-03-24
+# revised 2018-09-09
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -46,7 +47,8 @@ our @EXPORT = qw(D50 d50 d50P PI radian ln10 xyz2Lab Lab2xyz xyz2Lxyz Lxyz2xyz L
 XYZ2Lab Lab2XYZ XYZ2Lxyz Lxyz2XYZ XYZ2xyz xyz2XYZ XYZ2xyY xyY2XYZ x2L L2x dLdx dxdL XYZ2W xyz2dwv
 xyz2Lab_jac Lab2xyz_jac dEab dEcmc dE94 dE00 dE99 dCh CCT CCT2 bbrad bbxy bbuv XYZ2ucs xy2ucs daylight
 linear linear_matrix cspline cspline_matrix lagrange lagrange_matrix dotProduct crossProduct
-flatten clip_struct round s15f162v v2s15f16 makeProfileFolder getICCPath filterPath setFile);
+flatten clip_struct round s15f162v v2s15f16 makeProfileFolder getICCPath filterPath setFile parse_tokens
+is_vector is_num_vector is_matrix is_num_matrix);
 
 # add POSIX functions/constants
 push(@EXPORT, @{$POSIX::EXPORT_TAGS{'math_h'}});
@@ -69,10 +71,10 @@ sub copy {
 	return() if ($n == 0);
 
 	# verify number of copies is a positive integer
-	(! ref($n) && $n == int($n) && $n > 0) || croak('number of copies not a positive integer');
+	(! ref($n) && $n == int($n) && $n > 0) or croak('number of copies not a positive integer');
 
 	# verify parameter is a reference
-	(ref($self)) || croak("can't copy class $self");
+	(ref($self)) or croak("can't copy class $self");
 
 	# return copies
 	return(wantarray ? map {Storable::dclone($self)} (1 .. $n) : Storable::dclone($self));
@@ -89,7 +91,7 @@ sub dump {
 	my ($self, $format) = @_;
 
 	# verify object has 'sdump' method
-	($self->can('sdump')) || croak("object lacks 'sdump' method");
+	($self->can('sdump')) or croak("object lacks 'sdump' method");
 
 	# get string from 'sdump'
 	my $s = $self->sdump($format);
@@ -820,7 +822,7 @@ sub bbxy {
 	$Z = dotProduct($cmf->{'CIE1931z'}, $b);
 
 	# compute denominator
-	($d = $X + $Y + $Z) || croak('X + Y + Z = 0 when computing chromaticity');
+	($d = $X + $Y + $Z) or croak('X + Y + Z = 0 when computing chromaticity');
 
 	# return x,y
 	return($X/$d, $Y/$d);
@@ -855,7 +857,7 @@ sub bbuv {
 	$Z = dotProduct($cmf->{'CIE1931z'}, $b);
 
 	# compute denominator
-	($d = $X + 15 * $Y + 3 * $Z) || croak('X + 15Y + 3Z = 0 when computing UCS values');
+	($d = $X + 15 * $Y + 3 * $Z) or croak('X + 15Y + 3Z = 0 when computing UCS values');
 
 	# return u,v
 	return(4 * $X/$d, 6 * $Y/$d);
@@ -872,7 +874,7 @@ sub XYZ2ucs {
 	my ($X, $Y, $Z) = @_;
 
 	# compute denominator
-	(my $d = $X + 15 * $Y + 3 * $Z) || croak('X + 15Y + 3Z = 0 when computing UCS values');
+	(my $d = $X + 15 * $Y + 3 * $Z) or croak('X + 15Y + 3Z = 0 when computing UCS values');
 
 	# return u,v
 	return(4 * $X/$d, 6 * $Y/$d);
@@ -889,7 +891,7 @@ sub xy2ucs {
 	my ($x, $y) = @_;
 
 	# denominator
-	(my $d = 12 * $y - 2 * $x + 3) || croak('12Y - 2X + 3 = 0 when computing UCS values');
+	(my $d = 12 * $y - 2 * $x + 3) or croak('12Y - 2X + 3 = 0 when computing UCS values');
 
 	# return u,v
 	return(4 * $x/$d, 6 * $y/$d);
@@ -908,7 +910,7 @@ sub daylight {
 	my ($range, $spd, $xD, $yD, $M1, $M2);
 	
 	# verify color temperature
-	($cct >= 4000 && $cct <= 25000) || croak('CCT must be between 4000˚K and 25000˚K');
+	($cct >= 4000 && $cct <= 25000) or croak('CCT must be between 4000˚K and 25000˚K');
 
 	# load CIE daylight Eigenvectors (YAML format)
 	state $eigen = YAML::Tiny->read(getICCPath('Data/CIE_daylight_300-830_x_5.yml'))->[0];
@@ -968,16 +970,16 @@ sub linear {
 	my ($ix, $ox, $w, $vector_out, $t, $low);
 
 	# verify input vector size
-	(($ix = $#{$vector_in}) > 0) || croak('input vector must contain two or more elements');
+	(($ix = $#{$vector_in}) > 0) or croak('input vector must contain two or more elements');
 
 	# verify input range
-	(abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) || croak('invalid input range');
+	(abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) or croak('invalid input range');
 
 	# compute output upper index from range
-	(($ox = round(($range_out->[1] - $range_out->[0])/$range_out->[2])) > 0) || croak('output upper index must be > 0');
+	(($ox = round(($range_out->[1] - $range_out->[0])/$range_out->[2])) > 0) or croak('output upper index must be > 0');
 
 	# verify output range
-	(abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) || croak('invalid output range');
+	(abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) or croak('invalid output range');
 
 	# for each output vector element
 	for my $i (0 .. $ox) {
@@ -1108,13 +1110,13 @@ sub linear_matrix {
 	$ix = round(($range_in->[1] - $range_in->[0])/$range_in->[2]);
 
 	# verify input range
-	($ix > 0 && abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) || croak('invalid input range');
+	($ix > 0 && abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) or croak('invalid input range');
 
 	# compute output vector size from range
 	$ox = round(($range_out->[1] - $range_out->[0])/$range_out->[2]);
 
 	# verify output range
-	($ox > 0 && abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) || croak('invalid output range');
+	($ox > 0 && abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) or croak('invalid output range');
 
 	# if ICC::Support::Lapack module is loaded
 	if ($lapack) {
@@ -1237,16 +1239,16 @@ sub cspline {
 	my ($low, $t, $tc, $h00, $h01, $h10, $h11);
 
 	# verify input vector size
-	(($ix = $#{$vector_in}) > 0) || croak('input vector must contain two or more elements');
+	(($ix = $#{$vector_in}) > 0) or croak('input vector must contain two or more elements');
 
 	# verify input range
-	(abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) || croak('invalid input range');
+	(abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) or croak('invalid input range');
 
 	# compute output upper index from range
-	(($ox = round(($range_out->[1] - $range_out->[0])/$range_out->[2])) > 0) || croak('output upper index must be > 0');
+	(($ox = round(($range_out->[1] - $range_out->[0])/$range_out->[2])) > 0) or croak('output upper index must be > 0');
 
 	# verify output range
-	(abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) || croak('invalid output range');
+	(abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) or croak('invalid output range');
 
 	# check if ICC::Support::Lapack module is loaded
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
@@ -1425,13 +1427,13 @@ sub cspline_matrix {
 	$ix = round(($range_in->[1] - $range_in->[0])/$range_in->[2]);
 
 	# verify input range
-	($ix > 0 && abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) || croak('invalid input range');
+	($ix > 0 && abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) or croak('invalid input range');
 
 	# compute output vector size from range
 	$ox = round(($range_out->[1] - $range_out->[0])/$range_out->[2]);
 
 	# verify output range
-	($ox > 0 && abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) || croak('invalid output range');
+	($ox > 0 && abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) or croak('invalid output range');
 
 	# if ICC::Support::Lapack module is loaded
 	if ($lapack) {
@@ -1640,16 +1642,16 @@ sub lagrange {
 	my ($ix, $ox, $w, $vector_out, $t, $low);
 
 	# verify input vector size
-	(($ix = $#{$vector_in}) > 0) || croak('input vector must contain two or more elements');
+	(($ix = $#{$vector_in}) > 0) or croak('input vector must contain two or more elements');
 
 	# verify input range
-	(abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) || croak('invalid input range');
+	(abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) or croak('invalid input range');
 
 	# compute output upper index from range
-	(($ox = round(($range_out->[1] - $range_out->[0])/$range_out->[2])) > 0) || croak('output upper index must be > 0');
+	(($ox = round(($range_out->[1] - $range_out->[0])/$range_out->[2])) > 0) or croak('output upper index must be > 0');
 
 	# verify output range
-	(abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) || croak('invalid output range');
+	(abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) or croak('invalid output range');
 
 	# for each output vector element
 	for my $i (0 .. $ox) {
@@ -1810,13 +1812,13 @@ sub lagrange_matrix {
 	$ix = round(($range_in->[1] - $range_in->[0])/$range_in->[2]);
 
 	# verify input range
-	($ix > 0 && abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) || croak('invalid input range');
+	($ix > 0 && abs($ix * $range_in->[2] - $range_in->[1] + $range_in->[0]) < 1E-12 && $range_in->[2] > 0) or croak('invalid input range');
 
 	# compute output vector size from range
 	$ox = round(($range_out->[1] - $range_out->[0])/$range_out->[2]);
 
 	# verify output range
-	($ox > 0 && abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) || croak('invalid output range');
+	($ox > 0 && abs($ox * $range_out->[2] - $range_out->[1] + $range_out->[0]) < 1E-12 && $range_out->[2] > 0) or croak('invalid output range');
 
 	# if ICC::Support::Lapack module is loaded
 	if ($lapack) {
@@ -1980,7 +1982,7 @@ sub dotProduct {
 	} else {
 		
 		# verify vector sizes match
-		($#{$_[0]} == $#{$_[1]}) || croak('vector size mismatch');
+		($#{$_[0]} == $#{$_[1]}) or croak('vector size mismatch');
 		
 		# initialize sum
 		my $sum = 0;
@@ -2007,7 +2009,7 @@ sub dotProduct {
 sub crossProduct {
 
 	# verify vectors are three-dimensional
-	($#{$_[0]} == 2 && $#{$_[1]} == 2) || croak('vectors not three-dimensional');
+	($#{$_[0]} == 2 && $#{$_[1]} == 2) or croak('vectors not three-dimensional');
 
 	# return cross product
 	return([$_[0][1] * $_[1][2] - $_[0][2] * $_[1][1], $_[0][2] * $_[1][0] - $_[0][0] * $_[1][2], $_[0][0] * $_[1][1] - $_[0][1] * $_[1][0]]);
@@ -2016,9 +2018,9 @@ sub crossProduct {
 
 #--------- utility functions ---------
 
-# flatten slice
-# input is a reference to a structure consisting of scalars, arrays or Math::Matrix objects.
-# flatten converts the structure to a reference to an array of scalars.
+# flatten slice structure
+# structure may contain scalars, arrays or Math::Matrix objects
+# the structure is converted to an array of scalars
 # parameters: (ref_to_slice_structure)
 # returns: (reference_to_flattened_slice)
 sub flatten {
@@ -2065,13 +2067,13 @@ sub flatten {
 }
 
 # recursive clipping function
-# for a structure containing scalars and arrays
+# structure may contain scalars, arrays or Math::Matrix objects
 # clips scalar elements < 0.0 or > 1.0
-# parameter: (structure_ref)
+# parameter: (reference_to_structure)
 sub clip_struct {
 
-	# if an array reference
-	if (ref($_[0]) eq 'ARRAY') {
+	# if array reference or Math::Matrix object
+	if (ref($_[0]) eq 'ARRAY' || UNIVERSAL::isa($_[0], 'Math::Matrix')) {
 		
 		# for each array element
 		for (@{$_[0]}) {
@@ -2080,7 +2082,7 @@ sub clip_struct {
 			if (ref()) {
 				
 				# call myself
-				clip($_)
+				clip_struct($_)
 				
 			} else {
 				
@@ -2153,7 +2155,7 @@ sub makeProfileFolder {
 	my (@jobs, $i, $cust, $job, $folder, $sym);
 
 	# verify parameter is a valid path
-	(-e $path) || croak('invalid path parameter');
+	(-e $path) or croak('invalid path parameter');
 
 	# split the absolute path (note use of 'no_file' flag)
 	($vol, $dir, $file) = File::Spec->splitpath(File::Spec->rel2abs($path), -d $path);
@@ -2224,7 +2226,7 @@ sub makeProfileFolder {
 	if (defined($alias)) {
 		
 		# verify a valid directory
-		(-d $alias) || croak('invalid alias parameter');
+		(-d $alias) or croak('invalid alias parameter');
 		
 		# append alias folder name
 		$alias .= "/$sym";
@@ -2244,7 +2246,7 @@ sub makeProfileFolder {
 
 }
 
-# get distribution 'ICC' path
+# get 'ICC' directory path
 # optional parameter is appended to path
 # parameter: ([file/folder])
 # returns: (path)
@@ -2272,16 +2274,32 @@ sub getICCPath {
 }
 
 # filter file path
-# converts '~' to user home
-# removes '\' characters
+# replaces '~' with user home directory
+# removes '\' characters (Unix) or replaces '/' with '\' (Windows)
 # parameter: (file_path)
 sub filterPath {
 
-	# replace '~'
-	$_[0] =~ s/^~/$ENV{'HOME'}/;
+	# return if path undefined or a reference
+	return() if (! defined($_[0]) || ref($_[0]));
 
-	# remove '\'
-	$_[0] =~ s/\\//g;
+	# if Windows
+	if ($^O eq 'MSWin32') {
+		
+		# replace '~'
+		$_[0] =~ s/^~/$ENV{'USERPROFILE'}/;
+		
+		# replace '/' with '\'
+		$_[0]  =~ s/\//\\/g;
+		
+	} else {
+		
+		# replace '~'
+		$_[0] =~ s/^~/$ENV{'HOME'}/;
+
+		# remove '\'
+		$_[0] =~ s/\\//g;
+		
+	}
 
 }
 
@@ -2293,8 +2311,8 @@ sub setFile {
 	# get parameters
 	my ($path, $creator, $type) = @_;
 
-	# filter file path
-	filterPath($path);
+	# replace '~'
+	$path =~ s/^~/$ENV{'HOME'}/;
 
 	# escape spaces and special characters
 	$path =~ s/([^\w\-\/+.@])/\\$1/g;
@@ -2315,6 +2333,151 @@ sub setFile {
 
 }
 
+# parse token string
+# string is split into tokens
+# token parameters are processed with 'eval'
+# returned array contains tokens and their parameters
+# parameters: (token_string)
+# returns: (ref_to_array)
+sub parse_tokens {
+
+	# get parameter
+	my $str = shift();
+
+	# local parameters
+	my ($nest, $j, $char, @px, $sub, @pars, @eval);
+
+	# return if parameter undefined
+	return([]) if (! defined($str));
+
+	# if parameter not a scalar
+	if (ref($str)) {
+		
+		# warn
+		carp("invalid 'parse_token' parameter\n");
+		
+		# return
+		return([]);
+		
+	}
+
+	# initialize loop
+	$nest = 0;
+	$j = 0;
+
+	# for each character
+	for my $i (0 .. (length($str) - 1)) {
+		
+		# get character
+		$char = substr($str, $i, 1);
+		
+		# if a '('
+		if ($char eq '(') {
+			
+			# if first nesting level
+			if ($nest == 0) {
+				
+				# save index (start parameter group)
+				$px[$j]->[0] = $i;
+				
+			}
+			
+			# increment nesting level
+			$nest++;
+			
+		# if a ')'
+		} elsif ($char eq ')') {
+			
+			# if second nesting level
+			if ($nest == 1) {
+				
+				# save index (end parameter group)
+				$px[$j]->[1] = $i;
+				
+				# increment parameter index
+				$j++;
+				
+			}
+			
+			# decrement nesting level
+			$nest--;
+			
+		}
+		
+	}
+
+	# check final nesting level (should be 0)
+	carp("missing ')' in parameters\n") if ($nest > 0);
+	carp("missing '(' in parameters\n") if ($nest < 0);
+
+	# for each parameter group
+	for my $i (0 .. $#px) {
+		
+		# get parameter substring
+		$sub = substr($str, $px[$i]->[0], $px[$i]->[1] - $px[$i]->[0] + 1);
+		
+		# evaluate parameter substring
+		@eval = eval($sub);
+		
+		# split text within (), if 'eval' failed
+		@eval = split(/[\s,]+/, substr($str, $px[$i]->[0] + 1, $px[$i]->[1] - $px[$i]->[0] - 1)) if ((! @eval) && ($px[$i]->[1] - $px[$i]->[0] > 1));
+		
+		# save parameters
+		$pars[$i] = [@eval];
+		
+	}
+
+	# for each parameter group (reverse order)
+	for my $i (reverse(0 .. $#px)) {
+		
+		# replace parameter group with ' ($i) '
+		substr($str, $px[$i]->[0], $px[$i]->[1] - $px[$i]->[0] + 1) = " ($i) ";
+		
+	}
+
+	# split string into tokens, then replace '($i)' with 'eval'd parameters
+	return([map {m/\((\d+)\)/ ? $pars[$1] : $_} split(/[\s,]+/, $str)]);
+
+}
+
+#--------- testing parameters ---------
+
+# test if a vector
+# elements may be numeric or 'undef'
+sub is_vector {
+
+	# return test result
+	return(ref($_[0]) eq 'ARRAY' && @{$_[0]} == grep {! defined || Scalar::Util::looks_like_number($_)} @{$_[0]});
+
+}
+
+# test if a numeric vector
+# elements must all be numeric
+sub is_num_vector {
+
+	# return test result
+	return(ref($_[0]) eq 'ARRAY' && @{$_[0]} == grep {Scalar::Util::looks_like_number($_)} @{$_[0]});
+
+}
+
+# test if a matrix
+# elements may be numeric or 'undef'
+sub is_matrix {
+
+	# return test result
+	return((ref($_[0]) eq 'ARRAY' || ref($_[0]) eq 'Math::Matrix') && @{$_[0]} == grep {is_vector($_)} @{$_[0]});
+
+}
+
+# test if a numeric matrix
+# elements must all be numeric
+sub is_num_matrix {
+
+	# return test result
+	return((ref($_[0]) eq 'ARRAY' || ref($_[0]) eq 'Math::Matrix') && @{$_[0]} == grep {is_num_vector($_)} @{$_[0]});
+
+}
+
 #--------- internal functions ---------
 
 # convert structure (3 parameters)
@@ -2598,7 +2761,7 @@ sub _XYZ2xyY {
 	my ($X, $Y, $Z) = @_;
 
 	# compute denominator
-	(my $d = $X + $Y + $Z) || croak('X + Y + Z = 0 when computing chromaticity');
+	(my $d = $X + $Y + $Z) or croak('X + Y + Z = 0 when computing chromaticity');
 
 	# return values
 	return($X/$d, $Y/$d, $Y);
@@ -2725,6 +2888,51 @@ sub dump {
 
 }
 
+# clip matrix elements
+# default limits are [0, 1]
+# limit is disabled with value of 'none'
+# parameters: ([lower_limit], [upper_limit])
+# returns: (modified_matrix_object)
+sub clip {
+
+	# get parameters
+	my ($self, $low, $up) = @_;
+
+	# set defaults, as needed
+	$low = 0.0 if (! defined($low));
+	$low = undef if ($low eq 'none');
+	$up = 1.0 if (! defined($up));
+	$up = undef if ($up eq 'none');
+
+	# verify limits
+	(! defined($low) || Scalar::Util::looks_like_number($low)) or croak('invalid lower clipping limit');
+	(! defined($up) || Scalar::Util::looks_like_number($up)) or croak('invalid upper clipping limit');
+	(! defined($low) || ! defined($up) || $up >= $low) or croak('invalid clipping limits');
+
+	# for each row
+	for my $i (0 .. $#{$self}) {
+		
+		# for each column
+		for my $j (0 .. $#{$self->[$i]}) {
+			
+			# if matrix element is numeric
+			if (Scalar::Util::looks_like_number($self->[$i][$j])) {
+				
+				# apply limits to matrix element
+				$self->[$i][$j] = $low if (defined($low) && $self->[$i][$j] < $low);
+				$self->[$i][$j] = $up if (defined($up) && $self->[$i][$j] > $up);
+				
+			}
+			
+		}
+		
+	}
+
+	# return
+	return($self);
+
+}
+
 # exponentiate matrix elements
 # exponent may be a scalar or a vector
 # no testing, 'inf' or 'nan' values are possible
@@ -2753,7 +2961,7 @@ sub power {
 		if (! ref($x)) {
 		
 			# verify exponent is a number
-			(Scalar::Util::looks_like_number($x)) || croak('exponent must be a real number');
+			(Scalar::Util::looks_like_number($x)) or croak('exponent must be a real number');
 		
 			# for each row
 			for my $i (0 .. $#{$self}) {
@@ -2772,10 +2980,10 @@ sub power {
 		} elsif (ref($x) eq 'ARRAY') {
 		
 			# verify exponents are numbers
-			(@{$x} == grep {Scalar::Util::looks_like_number($_)} @{$x}) || croak('exponents must be real numbers');
+			(@{$x} == grep {Scalar::Util::looks_like_number($_)} @{$x}) or croak('exponents must be real numbers');
 		
 			# verify vector size same as column size
-			($#{$x} == $#{$self->[0]}) || croak('exponent vector wrong size');
+			($#{$x} == $#{$self->[0]}) or croak('exponent vector wrong size');
 		
 			# for each row
 			for my $i (0 .. $#{$self}) {
@@ -2817,7 +3025,7 @@ sub xyz2XYZ {
 	my ($mat);
 
 	# verify a 3x3 matrix
-	(@{$self} == 3 && @{$self->[0]} == 3) || croak('must be a 3x3 matrix');
+	(@{$self} == 3 && @{$self->[0]} == 3) or croak('must be a 3x3 matrix');
 
 	# set white point to D50 if undefined
 	$wtpt = [96.42, 100, 82.49] if (! defined($wtpt));
@@ -2856,7 +3064,7 @@ sub XYZ2xyz {
 	my ($mat);
 
 	# verify a 3x3 matrix
-	(@{$self} == 3 && @{$self->[0]} == 3) || croak('must be a 3x3 matrix');
+	(@{$self} == 3 && @{$self->[0]} == 3) or croak('must be a 3x3 matrix');
 
 	# set white point to D50 if undefined
 	$wtpt = [96.42, 100, 82.49] if (! defined($wtpt));
