@@ -5,7 +5,7 @@ use Carp;
 
 our $VERSION = 0.22;
 
-# revised 2017-08-04
+# revised 2017-09-08
 
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -147,16 +147,16 @@ sub illuminant {
 			if (@{$array}) {
 				
 				# verify array size
-				(@{$array} == 2) || croak('invalid illuminant array');
+				(@{$array} == 2) or croak('invalid illuminant array');
 				
 				# verify wavelength range
-				(ref($array->[0]) eq 'ARRAY' && 3 == @{$array->[0]} && (3 == grep {Scalar::Util::looks_like_number($_)} @{$array->[0]}) && $array->[0][2]) || croak('invalid illuminant wavelength range');
+				(ref($array->[0]) eq 'ARRAY' && 3 == @{$array->[0]} && (3 == grep {Scalar::Util::looks_like_number($_)} @{$array->[0]}) && $array->[0][2]) or croak('invalid illuminant wavelength range');
 				
 				# compute upper index of spd array
-				(($sx = ICC::Shared::round(($array->[0][1] - $array->[0][0])/$array->[0][2])) > 0) || croak('inconsistent illuminant wavelength range');
+				(($sx = ICC::Shared::round(($array->[0][1] - $array->[0][0])/$array->[0][2])) > 0) or croak('inconsistent illuminant wavelength range');
 				
 				# verify spd array
-				(ref($array->[1]) eq 'ARRAY' && $#{$array->[1]} == $sx && @{$array->[1]} == grep {Scalar::Util::looks_like_number($_)} @{$array->[1]}) || croak('invalid illuminant spd array');
+				(ref($array->[1]) eq 'ARRAY' && $#{$array->[1]} == $sx && @{$array->[1]} == grep {Scalar::Util::looks_like_number($_)} @{$array->[1]}) or croak('invalid illuminant spd array');
 				
 				# copy array contents
 				$self->[1] = Storable::dclone($array);
@@ -214,16 +214,16 @@ sub observer {
 			if (@{$array}) {
 				
 				# verify array size
-				(@{$array} == 2) || croak('invalid observer array');
+				(@{$array} == 2) or croak('invalid observer array');
 				
 				# verify wavelength range
-				(ref($array->[0]) eq 'ARRAY' && 3 == @{$array->[0]} && (3 == grep {Scalar::Util::looks_like_number($_)} @{$array->[0]}) && $array->[0][2]) || croak('invalid observer wavelength range');
+				(ref($array->[0]) eq 'ARRAY' && 3 == @{$array->[0]} && (3 == grep {Scalar::Util::looks_like_number($_)} @{$array->[0]}) && $array->[0][2]) or croak('invalid observer wavelength range');
 				
 				# compute upper index of observer matrix
-				(($sx = ICC::Shared::round(($array->[0][1] - $array->[0][0])/$array->[0][2])) > 0) || croak('inconsistent observer wavelength range');
+				(($sx = ICC::Shared::round(($array->[0][1] - $array->[0][0])/$array->[0][2])) > 0) or croak('inconsistent observer wavelength range');
 				
 				# verify observer matrix
-				((ref($array->[1]) eq 'ARRAY' || UNIVERSAL::isa($array->[1], 'Math::Matrix')) && ref($array->[1][0]) eq 'ARRAY' && $#{$array->[1][0]} == $sx && @{$array->[1][0]} == grep {Scalar::Util::looks_like_number($_)} @{$array->[1][0]}) || croak('invalid observer cmf matrix');
+				((ref($array->[1]) eq 'ARRAY' || UNIVERSAL::isa($array->[1], 'Math::Matrix')) && ref($array->[1][0]) eq 'ARRAY' && $#{$array->[1][0]} == $sx && @{$array->[1][0]} == grep {Scalar::Util::looks_like_number($_)} @{$array->[1][0]}) or croak('invalid observer cmf matrix');
 				
 				# copy array contents
 				$self->[2] = Storable::dclone($array);
@@ -280,16 +280,16 @@ sub cwf {
 			if (@{$array}) {
 				
 				# verify array size
-				(@{$array} == 2) || croak('invalid cwf array');
+				(@{$array} == 2) or croak('invalid cwf array');
 				
 				# verify wavelength range
-				(ref($array->[0]) eq 'ARRAY' && 3 == @{$array->[0]} && (3 == grep {Scalar::Util::looks_like_number($_)} @{$array->[0]}) && $array->[0][2]) || croak('invalid cwf wavelength range');
+				(ref($array->[0]) eq 'ARRAY' && 3 == @{$array->[0]} && (3 == grep {Scalar::Util::looks_like_number($_)} @{$array->[0]}) && $array->[0][2]) or croak('invalid cwf wavelength range');
 				
 				# compute upper index of cwf matrix
-				(($sx = ICC::Shared::round(($array->[0][1] - $array->[0][0])/$array->[0][2])) > 0) || croak('inconsistent cwf wavelength range');
+				(($sx = ICC::Shared::round(($array->[0][1] - $array->[0][0])/$array->[0][2])) > 0) or croak('inconsistent cwf wavelength range');
 				
 				# verify cwf matrix
-				((ref($array->[1]) eq 'ARRAY' || UNIVERSAL::isa($array->[1], 'Math::Matrix')) && ref($array->[1][0]) eq 'ARRAY' && $#{$array->[1][0]} == $sx && @{$array->[1][0]} == grep {Scalar::Util::looks_like_number($_)} @{$array->[1][0]}) || croak('invalid cwf weight matrix');
+				((ref($array->[1]) eq 'ARRAY' || UNIVERSAL::isa($array->[1], 'Math::Matrix')) && ref($array->[1][0]) eq 'ARRAY' && $#{$array->[1][0]} == $sx && @{$array->[1][0]} == grep {Scalar::Util::looks_like_number($_)} @{$array->[1][0]}) or croak('invalid cwf weight matrix');
 				
 				# copy array contents
 				$self->[3] = Storable::dclone($array);
@@ -353,7 +353,7 @@ sub transform {
 	my $h = ref($_[-1]) eq 'HASH' ? 1 : 0;
 
 	# verify color weight array
-	(defined($_[0]->[3][0]) && defined($_[0]->[3][1])) || croak('color weight array undefined');
+	(defined($_[0]->[3][0]) && defined($_[0]->[3][1])) or croak('color weight array undefined');
 
 	# if input a 'Math::Matrix' object
 	if (@_ == $h + 2 && UNIVERSAL::isa($_[1], 'Math::Matrix')) {
@@ -416,7 +416,7 @@ sub jacobian {
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
 
 	# get input spectral range
-	($range = $hash->{'range'} || $srh->{@{$in}}) || croak('spectral range must be specified');
+	($range = $hash->{'range'} || $srh->{@{$in}}) or croak('spectral range must be specified');
 
 	# if data increment == cwf increment
 	if ($range->[2] == $self->[3][0][2]) {
@@ -476,7 +476,7 @@ sub jacobian {
 		} elsif ($encoding eq 'xyz' && @{$jac} == 3) {
 			
 			# verify white point
-			($self->[5][0] && $self->[5][1] && $self->[5][2]) || croak('invalid illuminant white point');
+			($self->[5][0] && $self->[5][1] && $self->[5][2]) or croak('invalid illuminant white point');
 			
 			# for each XYZ
 			for my $i (0 .. 2) {
@@ -517,7 +517,7 @@ sub jacobian {
 			$out = _trans1($self, $in, $hash);
 			
 			# verify output
-			($out->[0] && $out->[1] && $out->[2] && $out->[3]) || croak('invalid density value');
+			($out->[0] && $out->[1] && $out->[2] && $out->[3]) or croak('invalid density value');
 			
 			# for each RGBV
 			for my $i (0 .. 3) {
@@ -621,7 +621,7 @@ sub _trans1 {
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
 
 	# get input spectral range
-	($range = $hash->{'range'} || $srh->{@{$in}}) || croak('spectral range must be specified');
+	($range = $hash->{'range'} || $srh->{@{$in}}) or croak('spectral range must be specified');
 
 	# if data increment == cwf increment
 	if ($range->[2] == $self->[3][0][2]) {
@@ -680,7 +680,7 @@ sub _trans2 {
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
 
 	# get input spectral range
-	($range = $hash->{'range'} || $srh->{@{$in->[0]}}) || croak('spectral range must be specified');
+	($range = $hash->{'range'} || $srh->{@{$in->[0]}}) or croak('spectral range must be specified');
 
 	# if data increment == cwf increment
 	if ($range->[2] == $self->[3][0][2]) {
@@ -1079,10 +1079,10 @@ sub _bandpass_fn {
 	my ($m, $v, @array, $sum);
 
 	# verify shape
-	($shape >= 0 && $shape <= 1) || croak('invalid shape parameter');
+	($shape >= 0 && $shape <= 1) or croak('invalid shape parameter');
 
 	# verify upper index
-	($ix == int($ix) && ! ($ix % 4)) || croak('invalid upper index');
+	($ix == int($ix) && ! ($ix % 4)) or croak('invalid upper index');
 
 	# if shape not rectangular
 	if ($shape) {
@@ -1128,10 +1128,10 @@ sub _conv_matrix {
 	my ($n, $p, @zeros, $mat);
 
 	# verify bandpass function
-	(@{$bpf} % 2) || croak('bandpass function must have odd number of elements');
+	(@{$bpf} % 2) or croak('bandpass function must have odd number of elements');
 
 	# verify row upper index
-	($ix == int($ix) && $ix >= 0) || croak('row upper index must be an integer >= 0');
+	($ix == int($ix) && $ix >= 0) or croak('row upper index must be an integer >= 0');
 
 	# compute upper column index
 	$n = $#{$bpf} * ($ix + 2)/2;
@@ -1193,7 +1193,7 @@ sub _adjust_cwf {
 	$off = abs(($range_data->[0] - $self->[3][0][0])/$range_data->[2]);
 
 	# verify offset is an integer
-	(abs($off - ICC::Shared::round($off)) < 1E-12) || croak('range offset not an integer');
+	(abs($off - ICC::Shared::round($off)) < 1E-12) or croak('range offset not an integer');
 
 	# adjust CWF matrix
 	$cwf = _adjust_matrix($self->[3][1], $self->[3][0], $range_data);
@@ -1477,13 +1477,13 @@ sub _cie {
 		$s = defined($array->[1]) ? $array->[1] : 1;
 		
 		# verify sample
-		(Scalar::Util::looks_like_number($s) && $s == int($s) && $s > 0 && $s <= $illum->size()) || croak('invalid sample number');
+		(Scalar::Util::looks_like_number($s) && $s == int($s) && $s > 0 && $s <= $illum->size()) or croak('invalid sample number');
 		
 		# set wavelength range
 		$self->[1][0] = $illum->nm();
 		
 		# set spectral values
-		($self->[1][1] = $illum->spectral([$s])->[0]) || croak('illuminant chart has no spectral data');
+		($self->[1][1] = $illum->spectral([$s])->[0]) or croak('illuminant chart has no spectral data');
 		
 	# if a standard illuminant (YAML file in data folder)
 	} elsif (@files = grep {-f} File::Glob::bsd_glob(ICC::Shared::getICCPath("Data/$array->[0]_illums_*.yml"))) {
@@ -1498,19 +1498,19 @@ sub _cie {
 		$self->[1][0] = [$w->[0], $w->[-1], $w->[1] - $w->[0]];
 		
 		# set spectral values
-		($self->[1][1] = $illum->{$array->[1]}) || croak('standard illuminant not found');
+		($self->[1][1] = $illum->{$array->[1]}) or croak('standard illuminant not found');
 		
 	# if illuminant is two array references (wavelength range and spd vectors)
 	} elsif (@{$array} == grep {ref() eq 'ARRAY'} @{$array}) {
 		
 		# verify wavelength range
-		(ref($array->[0]) eq 'ARRAY' && 3 == @{$array->[0]} && (3 == grep {Scalar::Util::looks_like_number($_)} @{$array->[0]}) && $array->[0][2]) || croak('invalid illuminant wavelength range');
+		(ref($array->[0]) eq 'ARRAY' && 3 == @{$array->[0]} && (3 == grep {Scalar::Util::looks_like_number($_)} @{$array->[0]}) && $array->[0][2]) or croak('invalid illuminant wavelength range');
 		
 		# compute upper index of spd array
-		(($sx = ICC::Shared::round(($array->[0][1] - $array->[0][0])/$array->[0][2])) > 0) || croak('inconsistent illuminant wavelength range');
+		(($sx = ICC::Shared::round(($array->[0][1] - $array->[0][0])/$array->[0][2])) > 0) or croak('inconsistent illuminant wavelength range');
 		
 		# verify spd array
-		(ref($array->[1]) eq 'ARRAY' && $#{$array->[1]} == $sx && @{$array->[1]} == grep {Scalar::Util::looks_like_number($_)} @{$array->[1]}) || croak('invalid illuminant spd array');
+		(ref($array->[1]) eq 'ARRAY' && $#{$array->[1]} == $sx && @{$array->[1]} == grep {Scalar::Util::looks_like_number($_)} @{$array->[1]}) or croak('invalid illuminant spd array');
 		
 		# copy array contents
 		$self->[1] = Storable::dclone($array);
@@ -1557,18 +1557,18 @@ sub _cie {
 	if (ref($obs) eq 'ARRAY') {
 		
 		# verify array size
-		(@{$obs} == 2) || croak('invalid observer array');
+		(@{$obs} == 2) or croak('invalid observer array');
 		
 		# verify range
 		(ref($obs->[0]) eq 'ARRAY' && (@{$obs->[0]} == grep {Scalar::Util::looks_like_number($_)} @{$obs->[0]}) &&
-		@{$obs->[0]} == 3 && $obs->[0][2] && ! (($obs->[0][1] - $obs->[0][0]) % $obs->[0][2])) || croak('invalid observer wavelength range');
+		@{$obs->[0]} == 3 && $obs->[0][2] && ! (($obs->[0][1] - $obs->[0][0]) % $obs->[0][2])) or croak('invalid observer wavelength range');
 		
 		# compute upper index of observer matrix
-		(($sx = ICC::Shared::round(($obs->[0][1] - $obs->[0][0])/$obs->[0][2])) > 0) || croak('inconsistent observer wavelength range');
+		(($sx = ICC::Shared::round(($obs->[0][1] - $obs->[0][0])/$obs->[0][2])) > 0) or croak('inconsistent observer wavelength range');
 		
 		# verify observer matrix
 		((ref($obs->[1]) eq 'ARRAY' || UNIVERSAL::isa($obs->[1], 'Math::Matrix')) && ref($obs->[1][0]) eq 'ARRAY' &&
-		$#{$obs->[1][0]} == $sx && @{$obs->[1][0]} == grep {Scalar::Util::looks_like_number($_)} @{$obs->[1][0]}) || croak('invalid observer cmf matrix');
+		$#{$obs->[1][0]} == $sx && @{$obs->[1][0]} == grep {Scalar::Util::looks_like_number($_)} @{$obs->[1][0]}) or croak('invalid observer cmf matrix');
 		
 		# copy array contents
 		$self->[2] = Storable::dclone($obs);
@@ -1576,7 +1576,7 @@ sub _cie {
 	} else {
 		
 		# get observer key
-		($key = {'2' => 'CIE1931', '10' => 'CIE1964', '2P' => 'CIE2012D2', '10P' => 'CIE2012D10'}->{$obs}) || croak('invalid observer key');
+		($key = {'2' => 'CIE1931', '10' => 'CIE1964', '2P' => 'CIE2012D2', '10P' => 'CIE2012D10'}->{$obs}) or croak('invalid observer key');
 		
 		# set CIE color-matching functions
 		$self->[2][1][0] = $cmf->{$key . 'x'};
@@ -1779,35 +1779,6 @@ sub _smoothness {
 
 }
 
-# get file list
-# parameter: (path)
-# returns: (ref_to_file_list)
-sub _files {
-
-	# get path
-	my $path = shift();
-
-	# get list of files and/or directories
-	my @files = grep {-e} File::Glob::bsd_glob($path);
-
-	# if list is just one directory
-	if (@files == 1 && -d $files[0]) {
-	
-		# get files in that directory
-		@files = grep {-f} File::Glob::bsd_glob("$path/*");
-	
-	} else {
-	
-		# filter the files
-		@files = grep {-f} @files;
-	
-	}
-
-	# return file list
-	return(\@files);
-
-}
-
 # get encoding CODE reference
 # parameter(object_reference, hash)
 # returns: (CODE_reference)
@@ -1841,7 +1812,7 @@ sub _encoding {
 		} elsif ($encoding eq 'xyz' && $size == 3) {
 			
 			# verify white point
-			($self->[5][0] && $self->[5][1] && $self->[5][2]) || croak('invalid illuminant white point');
+			($self->[5][0] && $self->[5][1] && $self->[5][2]) or croak('invalid illuminant white point');
 			
 			# return code reference
 			return(sub {$_[0]/$self->[5][0], $_[1]/$self->[5][1], $_[2]/$self->[5][2]});
@@ -1891,13 +1862,13 @@ sub _new_from_hash {
 	if (defined($range = $hash->{'range'})) {
 		
 		# verify wavelength range structure
-		(ref($range) eq 'ARRAY' && 3 == @{$range} && (3 == grep {Scalar::Util::looks_like_number($_)} @{$range})) || croak('invalid wavelength range structure');
+		(ref($range) eq 'ARRAY' && 3 == @{$range} && (3 == grep {Scalar::Util::looks_like_number($_)} @{$range})) or croak('invalid wavelength range structure');
 		
 		# compute upper index
 		$ox = ICC::Shared::round(($range->[1] - $range->[0])/$range->[2]);
 		
 		# verify wavelength range values
-		($ox > 0 && abs($ox * $range->[2] - $range->[1] + $range->[0]) < 1E-12 && $range->[2] > 0) || croak('invalid wavelength range values');
+		($ox > 0 && abs($ox * $range->[2] - $range->[1] + $range->[0]) < 1E-12 && $range->[2] > 0) or croak('invalid wavelength range values');
 		
 		# add range to hash
 		$srh->{$ox + 1} = $range;
