@@ -3,9 +3,9 @@ package ICC::Support::PCS;
 use strict;
 use Carp;
 
-our $VERSION = 0.73;
+our $VERSION = 0.74;
 
-# revised 2017-07-08
+# revised 2018-05-12
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -60,21 +60,21 @@ sub new {
 
 	# get object class
 	my $class = shift();
-	
+
 	# create empty PCS object
 	my $self = [
-			{},		# object header
-			[],		# parameter array
-			[],		# tone compression array
-			0		# clipping flag
+		{}, # object header
+		[], # parameter array
+		[], # tone compression array
+		0   # clipping flag
 	];
-	
+
 	# if 2 or 3 parameters
 	if (@_ == 2 || @_ == 3) {
 		
 		# create new object from parameters
 		_new_pcs($self, @_);
-	
+		
 	# if any parameters
 	} elsif (@_) {
 		
@@ -82,13 +82,44 @@ sub new {
 		croak('wrong number of parameters');
 		
 	}
-	
+
 	# bless object
 	bless($self, $class);
-	
+
 	# return object reference
 	return($self);
-	
+
+}
+
+# get/set reference to header hash
+# parameters: ([ref_to_new_hash])
+# returns: (ref_to_hash)
+sub header {
+
+	# get object reference
+	my $self = shift();
+
+	# if there are parameters
+	if (@_) {
+		
+		# if one parameter, a hash reference
+		if (@_ == 1 && ref($_[0]) eq 'HASH') {
+			
+			# set header to new hash
+			$self->[0] = {%{shift()}};
+			
+		} else {
+			
+			# error
+			croak('parameter must be a hash reference');
+			
+		}
+		
+	}
+
+	# return reference
+	return($self->[0]);
+
 }
 
 # get/set clipping flag
@@ -160,36 +191,74 @@ sub linearity {
 # set input/output gamut scale
 # sets input/output black point vector to the white point vector x (1 - scale)
 # a zero value leaves the corresponding black point unchanged
-# parameters: (input_gamut_scale_factor, output_gamut_scale_factor)
+# parameters: ([input_gamut_scale_factor, output_gamut_scale_factor])
+# returns: (input_gamut_scale_factor, output_gamut_scale_factor)
 sub scale {
-	
+
 	# get object reference
 	my $self = shift();
-	
-	# verify parameters
-	(@_ == 2 && 2 == grep {! ref()} @_) || croak('invalid scale inputs');
-	
-	# for input and output
-	for my $i (0 .. 1) {
+
+	# local variable
+	my (@scale);
+
+	# if no parameters
+	if (@_ == 0) {
 		
-		# if gamut scale factor != 0, and white point defined
-		if ($_[$i] != 0 && defined($self->[1][$i][1])) {
+		# for each scale factor
+		for my $i (0 .. 1) {
 			
-			# for XYZ
-			for my $j (0 .. 2) {
+			# if white point and black point are defined
+			if (defined($self->[1][$i][1]) && defined($self->[1][$i][2]) && $self->[1][$i][1][1] != 0) {
 				
-				# set black point to scaled white point value
-				$self->[1][$i][2][$j] = (1 - $_[$i]) * $self->[1][$i][1][$j];
+				# set scale value
+				$scale[$i] = 1 - ($self->[1][$i][2][1]/$self->[1][$i][1][1]);
+				
+			} else {
+				
+				# set scale value
+				$scale[$i] = 0;
 				
 			}
 			
 		}
 		
+		# return
+		return(@scale);
+		
+	# if two numeric parameters
+	} elsif (@_ == 2 && 2 == grep {Scalar::Util::looks_like_number($_)} @_) {
+		
+		# for each scale factor
+		for my $i (0 .. 1) {
+			
+			# if gamut scale factor != 0, and white point defined
+			if ($_[$i] != 0 && defined($self->[1][$i][1])) {
+				
+				# for XYZ
+				for my $j (0 .. 2) {
+					
+					# set black point to scaled white point value
+					$self->[1][$i][2][$j] = (1 - $_[$i]) * $self->[1][$i][1][$j];
+					
+				}
+				
+			}
+			
+		}
+		
+		# update tone compression coefficients
+		tc_pars($self);
+		
+		# return
+		return(@_);
+		
+	} else {
+		
+		# error
+		croak('invalid scale inputs');
+		
 	}
 	
-	# update tone compression coefficients
-	tc_pars($self);
-	
 }
 
 # transform data
@@ -316,7 +385,7 @@ sub jacobian {
 	my ($pcsi, $pcso, @t, @d, $jac);
 
 	# verify 3 channels
-	(@{$in} == 3) || croak('PCS object input not 3 channels');
+	(@{$in} == 3) or croak('PCS object input not 3 channels');
 
 	# get input PCS
 	$pcsi = $self->[1][0][0];
@@ -719,7 +788,7 @@ sub _transform {
 	my ($i, $pcsi, $pcso, @t);
 
 	# verify 3 input channels
-	(@in == 3) || croak('PCS object input not 3 channels');
+	(@in == 3) or croak('PCS object input not 3 channels');
 
 	# get input PCS
 	$pcsi = $self->[1][$dir][0];
@@ -1471,13 +1540,13 @@ sub _new_pcs {
 	for my $i (0 .. 1) {
 		
 		# verify parameter is an array reference
-		(ref($_[$i]) eq 'ARRAY') || croak("$io[$i] parameter not an array reference");
+		(ref($_[$i]) eq 'ARRAY') or croak("$io[$i] parameter not an array reference");
 		
 		# verify number of array parameters
-		(@{$_[$i]} >= 1 || @{$_[$i]} <= 3) || croak("$io[$i] array has wrong number parameters");
+		(@{$_[$i]} >= 1 || @{$_[$i]} <= 3) or croak("$io[$i] array has wrong number parameters");
 		
 		# verify color space
-		(grep {$_[$i][0] == $_} @cs) || croak("$io[$i] color space not supported");
+		(grep {$_[$i][0] == $_} @cs) or croak("$io[$i] color space not supported");
 		
 		# copy color space
 		$self->[1][$i][0] = $_[$i][0];
@@ -1486,10 +1555,10 @@ sub _new_pcs {
 		if (defined($_[$i][1])) {
 			
 			# verify white point is an array reference
-			(ref($_[$i][1]) eq 'ARRAY') || croak("$io[$i] white point not an array reference");
+			(ref($_[$i][1]) eq 'ARRAY') or croak("$io[$i] white point not an array reference");
 			
 			# verify array structure
-			(3 == grep {! ref()} @{$_[$i][1]}) || croak("$io[$i] white point array has wrong structure");
+			(3 == grep {! ref()} @{$_[$i][1]}) or croak("$io[$i] white point array has wrong structure");
 			
 			# copy white point (converting XYZNumber to xyz)
 			$self->[1][$i][1] = [$_[$i][1][0]/ICC::Shared::d50->[0], $_[$i][1][1]/ICC::Shared::d50->[1], $_[$i][1][2]/ICC::Shared::d50->[2]];
@@ -1505,10 +1574,10 @@ sub _new_pcs {
 		if (defined($_[$i][2])) {
 			
 			# verify black point is an array reference
-			(ref($_[$i][2]) eq 'ARRAY') || croak("$io[$i] black point not an array reference");
+			(ref($_[$i][2]) eq 'ARRAY') or croak("$io[$i] black point not an array reference");
 			
 			# verify array structure
-			(3 == grep {! ref()} @{$_[$i][2]}) || croak("$io[$i] black point array has wrong structure");
+			(3 == grep {! ref()} @{$_[$i][2]}) or croak("$io[$i] black point array has wrong structure");
 			
 			# copy black point (converting XYZNumber to xyz)
 			$self->[1][$i][2] = [$_[$i][2][0]/ICC::Shared::d50->[0], $_[$i][2][1]/ICC::Shared::d50->[1], $_[$i][2][2]/ICC::Shared::d50->[2]];
