@@ -111,10 +111,10 @@ sub points {
 	if (defined($points)) {
 		
 		# verify an array reference
-		(ref($points) eq 'ARRAY') || croak('\'points\' parameter not an array');
+		(ref($points) eq 'ARRAY') or croak('\'points\' parameter not an array');
 		
 		# verify point coordinates
-		(@{$points} == grep {Scalar::Util::looks_like_number($_)} @{$points}) || croak('\'points\' array contains invalid coordinates');
+		(@{$points} == grep {Scalar::Util::looks_like_number($_)} @{$points}) or croak('\'points\' array contains invalid coordinates');
 		
 		# copy points array
 		$self->[1] = [@{$points}];
@@ -138,13 +138,13 @@ sub matrix {
 	if (defined($matrix)) {
 		
 		# verify a 2-D array or Math::Matrix object
-		((ref($matrix) eq 'ARRAY' && @{$matrix} == grep {ref() eq 'ARRAY'} @{$matrix}) || UNIVERSAL::isa($matrix, 'Math::Matrix')) || croak('\'matrix\' parameter not a 2-D array or Math::Matrix object');
+		((ref($matrix) eq 'ARRAY' && @{$matrix} == grep {ref() eq 'ARRAY'} @{$matrix}) || UNIVERSAL::isa($matrix, 'Math::Matrix')) or croak('\'matrix\' parameter not a 2-D array or Math::Matrix object');
 		
 		# verify first row contains only numeric values
-		(@{$matrix->[0]} == grep {Scalar::Util::looks_like_number($_)} @{$matrix->[0]}) || croak('\'matrix\' parameter contains non-numeric values');
+		(@{$matrix->[0]} == grep {Scalar::Util::looks_like_number($_)} @{$matrix->[0]}) or croak('\'matrix\' parameter contains non-numeric values');
 		
 		# verify matrix is square
-		(@{$matrix} == @{$matrix->[0]}) || croak('\'matrix\' parameter not square matrix');
+		(@{$matrix} == @{$matrix->[0]}) or croak('\'matrix\' parameter not square matrix');
 		
 		# copy weight matrix
 		$self->[2] = Storable::dclone($matrix);
@@ -267,10 +267,10 @@ sub _new_from_hash {
 	if ($points = $hash->{'points'}) {
 		
 		# verify an array reference
-		(ref($points) eq 'ARRAY') || croak('\'points\' parameter not an array');
+		(ref($points) eq 'ARRAY') or croak('\'points\' parameter not an array');
 		
 		# verify point coordinates
-		(@{$points} == grep {Scalar::Util::looks_like_number($_)} @{$points}) || croak('\'points\' array contains invalid coordinates');
+		(@{$points} == grep {Scalar::Util::looks_like_number($_)} @{$points}) or croak('\'points\' array contains invalid coordinates');
 		
 		# copy points array
 		$self->[1] = [@{$points}];
@@ -281,16 +281,16 @@ sub _new_from_hash {
 	if ($matrix = $hash->{'matrix'}) {
 		
 		# verify a 2-D array or Math::Matrix object
-		((ref($matrix) eq 'ARRAY' && @{$matrix} == grep {ref() eq 'ARRAY'} @{$matrix}) || UNIVERSAL::isa($matrix, 'Math::Matrix')) || croak('\'matrix\' parameter not a 2-D array or Math::Matrix object');
+		((ref($matrix) eq 'ARRAY' && @{$matrix} == grep {ref() eq 'ARRAY'} @{$matrix}) || UNIVERSAL::isa($matrix, 'Math::Matrix')) or croak('\'matrix\' parameter not a 2-D array or Math::Matrix object');
 		
 		# verify first row contains only numeric values
-		(@{$matrix->[0]} == grep {Scalar::Util::looks_like_number($_)} @{$matrix->[0]}) || croak('\'matrix\' parameter contains non-numeric values');
+		(@{$matrix->[0]} == grep {Scalar::Util::looks_like_number($_)} @{$matrix->[0]}) or croak('\'matrix\' parameter contains non-numeric values');
 		
 		# verify matrix is square
-		(@{$matrix} == @{$matrix->[0]}) || croak('\'matrix\' parameter not square matrix');
+		(@{$matrix} == @{$matrix->[0]}) or croak('\'matrix\' parameter not square matrix');
 		
 		# verify matrix and center have same dimensions
-		(@{$matrix} == @{$self->[1]}) || croak('\'matrix\' and \'center\' have different dimensions');
+		(@{$matrix} == @{$self->[1]}) or croak('\'matrix\' and \'center\' have different dimensions');
 		
 		# copy weight matrix
 		$self->[2] = Storable::dclone($matrix);
