@@ -1092,10 +1092,10 @@ sub _new_from_chart {
 	my ($dev, $fmt, $devc, $cs);
 
 	# verify chart has device values
-	($dev = $chart->device()) || croak('chart must have device values');
+	($dev = $chart->device()) or croak('chart must have device values');
 
 	# verify clut column slice is defined
-	(defined($cols) || ($cols = $chart->spectral() || $chart->xyz())) || croak('clut data slice is undefined');
+	(defined($cols) || ($cols = $chart->spectral() || $chart->xyz())) or croak('clut data slice is undefined');
 
 	# get format keys
 	$fmt = $chart->fmt_keys($cols);
@@ -1115,7 +1115,7 @@ sub _new_from_chart {
 		}
 		
 		# get corner point samples
-		($cs = $chart->ramp(sub {@{$devc} == grep {$devc->[$_] == $_[$_]} (0 .. $#{$devc})})) || croak("no chart samples for corner point [@{$devc}]\n");
+		($cs = $chart->ramp(sub {@{$devc} == grep {$devc->[$_] == $_[$_]} (0 .. $#{$devc})})) or croak("no chart samples for corner point [@{$devc}]\n");
 		
 		# save clut vector
 		$self->[1][$i] = $chart->slice($chart->add_avg($cs), $cols)->[0];
