@@ -114,19 +114,19 @@ sub fit {
 	$oflag = 0 if (! defined($oflag));
 
 	# verify input array
-	(ref($in) eq 'ARRAY' && ref($in->[0]) eq 'ARRAY' && ! ref($in->[0][0])) || (UNIVERSAL::isa($in, 'Math::Matrix')) || croak('fit input not a 2-D array reference');
+	(ref($in) eq 'ARRAY' && ref($in->[0]) eq 'ARRAY' && ! ref($in->[0][0])) || (UNIVERSAL::isa($in, 'Math::Matrix')) or croak('fit input not a 2-D array reference');
 
 	# verify output array
-	(ref($out) eq 'ARRAY' && ref($out->[0]) eq 'ARRAY' && ! ref($out->[0][0])) || (UNIVERSAL::isa($out, 'Math::Matrix')) || croak('fit output not a 2-D array reference');
+	(ref($out) eq 'ARRAY' && ref($out->[0]) eq 'ARRAY' && ! ref($out->[0][0])) || (UNIVERSAL::isa($out, 'Math::Matrix')) or croak('fit output not a 2-D array reference');
 
 	# verify array dimensions
-	($#{$in} == $#{$out}) || croak('fit input and output arrays have different number of rows');
+	($#{$in} == $#{$out}) or croak('fit input and output arrays have different number of rows');
 
 	# if difference mode
 	if ($dflag) {
 		
 		# verify array dimensions
-		($#{$in->[0]} == $#{$out->[0]}) || croak('fit input and output arrays have different number of columns');
+		($#{$in->[0]} == $#{$out->[0]}) or croak('fit input and output arrays have different number of columns');
 		
 		# for each row
 		for my $i (0 .. $#{$in}) {
@@ -434,7 +434,7 @@ sub inverse {
 	$i = $j = -1;
 
 	# build slice arrays while validating input and output arrays
-	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) || croak('wrong number of undefined values');
+	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) or croak('wrong number of undefined values');
 
 	# get init array
 	$init = $hash->{'init'};
