@@ -116,13 +116,13 @@ sub fit {
 	my ($info, $hidden, $ab);
 
 	# verify input array
-	(ref($in) eq 'ARRAY' && ref($in->[0]) eq 'ARRAY' && ! ref($in->[0][0])) || (UNIVERSAL::isa($in, 'Math::Matrix')) || croak('fit input not a 2-D array reference');
+	(ref($in) eq 'ARRAY' && ref($in->[0]) eq 'ARRAY' && ! ref($in->[0][0])) || (UNIVERSAL::isa($in, 'Math::Matrix')) or croak('fit input not a 2-D array reference');
 
 	# verify output array
-	(ref($out) eq 'ARRAY' && ref($out->[0]) eq 'ARRAY' && ! ref($out->[0][0])) || (UNIVERSAL::isa($out, 'Math::Matrix')) || croak('fit output not a 2-D array reference');
+	(ref($out) eq 'ARRAY' && ref($out->[0]) eq 'ARRAY' && ! ref($out->[0][0])) || (UNIVERSAL::isa($out, 'Math::Matrix')) or croak('fit output not a 2-D array reference');
 
 	# verify array dimensions
-	($#{$in} == $#{$out}) || croak('fit input and output arrays have different number of rows');
+	($#{$in} == $#{$out}) or croak('fit input and output arrays have different number of rows');
 
 	# compute hidden array
 	$hidden = _hidden2($self, $in);
@@ -176,7 +176,7 @@ sub header {
 	if (defined($header)) {
 		
 		# verify a hash reference
-		(ref($header) eq 'HASH') || croak('\'nNET2\' header wrong data type');
+		(ref($header) eq 'HASH') or croak('\'nNET2\' header wrong data type');
 		
 		# copy header hash
 		$self->[0] = {%{$header}};
@@ -200,7 +200,7 @@ sub kernel {
 	if (defined($kernel)) {
 		
 		# verify an array reference
-		(ref($kernel) eq 'ARRAY') || croak('\'nNET2\' kernel wrong data type');
+		(ref($kernel) eq 'ARRAY') or croak('\'nNET2\' kernel wrong data type');
 		
 		# initialize object array
 		$self->[1] = [];
@@ -242,7 +242,7 @@ sub hidden {
 	if (defined($hidden)) {
 		
 		# verify an array reference
-		(ref($hidden) eq 'ARRAY') || croak('\'nNET2\' hidden wrong data type');
+		(ref($hidden) eq 'ARRAY') or croak('\'nNET2\' hidden wrong data type');
 		
 		# initialize object array
 		$self->[2] = [];
@@ -284,7 +284,7 @@ sub matrix {
 	if (defined($matrix)) {
 		
 		# verify a 2-D array reference or Math::Matrix object
-		((ref($matrix) eq 'ARRAY' && @{$matrix} == grep {ref() eq 'ARRAY'} @{$matrix}) || UNIVERSAL::isa($matrix, 'Math::Matrix')) || croak('\'nNET2\' matrix wrong data type');
+		((ref($matrix) eq 'ARRAY' && @{$matrix} == grep {ref() eq 'ARRAY'} @{$matrix}) || UNIVERSAL::isa($matrix, 'Math::Matrix')) or croak('\'nNET2\' matrix wrong data type');
 		
 		# copy matrix
 		$self->[3] = Storable::dclone($matrix);
@@ -308,7 +308,7 @@ sub offset {
 	if (defined($offset)) {
 		
 		# verify a reference to array of scalars
-		(ref($offset) eq 'ARRAY' && @{$offset} == grep {! ref()} @{$offset}) || croak('\'nNET2\' offset wrong data type');
+		(ref($offset) eq 'ARRAY' && @{$offset} == grep {! ref()} @{$offset}) or croak('\'nNET2\' offset wrong data type');
 		
 		# copy offset
 		$self->[4] = [@{$offset}];
@@ -332,7 +332,7 @@ sub add_kernel {
 	my (@gx);
 
 	# verify add_kernel parameter supplied
-	(defined($kernel)) || carp('\'nNET2\' add_kernel parameter undefined');
+	(defined($kernel)) or carp('\'nNET2\' add_kernel parameter undefined');
 
 	# wrap if not an array reference
 	$kernel = [$kernel] if (ref($kernel) ne 'ARRAY');
@@ -375,7 +375,7 @@ sub add_hidden {
 	my (@hx);
 
 	# verify add_hidden parameter supplied
-	(defined($hidden)) || carp('\'nNET2\' add_hidden parameter undefined');
+	(defined($hidden)) or carp('\'nNET2\' add_hidden parameter undefined');
 
 	# wrap if not an array reference
 	$hidden = [$hidden] if (ref($hidden) ne 'ARRAY');
@@ -482,7 +482,7 @@ sub inverse {
 	$i = $j = -1;
 
 	# build slice arrays while validating input and output arrays
-	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) || croak('wrong number of undefined values');
+	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) or croak('wrong number of undefined values');
 
 	# get init array
 	$init = $hash->{'init'};
@@ -973,7 +973,7 @@ sub _new_from_hash {
 	if ($header = $hash->{'header'}) {
 		
 		# verify a hash reference
-		(ref($header) eq 'HASH') || croak('\'nNET\' header wrong data type');
+		(ref($header) eq 'HASH') or croak('\'nNET\' header wrong data type');
 		
 		# copy header hash
 		$self->[0] = {%{$header}};
@@ -984,7 +984,7 @@ sub _new_from_hash {
 	if ($kernel = $hash->{'kernel'}) {
 		
 		# verify an array reference
-		(ref($kernel) eq 'ARRAY') || croak('\'nNET\' kernel wrong data type');
+		(ref($kernel) eq 'ARRAY') or croak('\'nNET\' kernel wrong data type');
 		
 		# for each kernel element
 		for my $i (0 .. $#{$kernel}) {
@@ -1010,7 +1010,7 @@ sub _new_from_hash {
 	if ($hidden = $hash->{'hidden'}) {
 		
 		# verify an array reference
-		(ref($hidden) eq 'ARRAY') || croak('\'nNET\' hidden wrong data type');
+		(ref($hidden) eq 'ARRAY') or croak('\'nNET\' hidden wrong data type');
 		
 		# for each hidden element
 		for my $i (0 .. $#{$hidden}) {
@@ -1036,7 +1036,7 @@ sub _new_from_hash {
 	if ($matrix = $hash->{'matrix'}) {
 		
 		# verify a 2-D array reference or Math::Matrix object
-		((ref($matrix) eq 'ARRAY' && @{$matrix} == grep {ref() eq 'ARRAY'} @{$matrix}) || UNIVERSAL::isa($matrix, 'Math::Matrix')) || croak('\'nNET\' matrix wrong data type');
+		((ref($matrix) eq 'ARRAY' && @{$matrix} == grep {ref() eq 'ARRAY'} @{$matrix}) || UNIVERSAL::isa($matrix, 'Math::Matrix')) or croak('\'nNET\' matrix wrong data type');
 		
 		# copy matrix
 		$self->[3] = Storable::dclone($matrix);
@@ -1047,7 +1047,7 @@ sub _new_from_hash {
 	if ($offset = $hash->{'offset'}) {
 		
 		# verify a reference to array of scalars
-		(ref($offset) eq 'ARRAY' && @{$offset} == grep {! ref()} @{$offset}) || croak('\'nNET\' offset wrong data type');
+		(ref($offset) eq 'ARRAY' && @{$offset} == grep {! ref()} @{$offset}) or croak('\'nNET\' offset wrong data type');
 		
 		# copy offset
 		$self->[4] = [@{$offset}];
@@ -1058,7 +1058,7 @@ sub _new_from_hash {
 	if ($init = $hash->{'init'}) {
 		
 		# verify a CODE reference
-		(ref($init) eq 'CODE') || croak('\'nNET\' init wrong data type');
+		(ref($init) eq 'CODE') or croak('\'nNET\' init wrong data type');
 		
 		# set init
 		$self->[0]{'init'} = $init;
