@@ -3,9 +3,9 @@ package ICC::Support::nPINT;
 use strict;
 use Carp;
 
-our $VERSION = 0.71;
+our $VERSION = 0.72;
 
-# revised 2016-05-17
+# revised 2018-09-08
 #
 # Copyright © 2004-2018 by William B. Birkett
 
@@ -16,7 +16,6 @@ use lib 'lib';
 use parent qw(ICC::Shared);
 
 # support modules
-use File::Glob;
 use POSIX ();
 
 =encoding utf-8
@@ -68,7 +67,7 @@ sub new {
 	} elsif (@_) {
 		
 		# create new object from Storable file
-		_new_from_storable($self, @_) || carp("couldn't read Storable file: $_[0]");
+		_new_from_storable($self, @_) or carp("couldn't read Storable file: $_[0]");
 		
 	}
 
@@ -96,19 +95,19 @@ sub fit {
 	$cols = ICC::Support::Lapack::xcols($pda);
 	
 	# verify input is an array or Math::Matrix object
-	(ref($in) eq 'ARRAY' || UNIVERSAL::isa($in, 'Math::Matrix')) || croak('improper input array type');
+	(ref($in) eq 'ARRAY' || UNIVERSAL::isa($in, 'Math::Matrix')) or croak('improper input array type');
 
 	# verify input structure
-	(ref($in->[0]) eq 'ARRAY' && ! ref($in->[0][0])) || croak('improper input array structure');
+	(ref($in->[0]) eq 'ARRAY' && ! ref($in->[0][0])) or croak('improper input array structure');
 
 	# verify output is an array or Math::Matrix object
-	(ref($out) eq 'ARRAY' || UNIVERSAL::isa($out, 'Math::Matrix')) || croak('improper output array type');
+	(ref($out) eq 'ARRAY' || UNIVERSAL::isa($out, 'Math::Matrix')) or croak('improper output array type');
 
 	# verify output structure
-	(ref($out->[0]) eq 'ARRAY' && ! ref($out->[0][0])) || croak('improper output array structure');
+	(ref($out->[0]) eq 'ARRAY' && ! ref($out->[0][0])) or croak('improper output array structure');
 
 	# verify array dimensions
-	($#{$in} == $#{$out}) || croak('fit input and output arrays have different number of rows');
+	($#{$in} == $#{$out}) or croak('fit input and output arrays have different number of rows');
 
 	# fit nPINT model
 	($info, $coef) = ICC::Support::Lapack::nPINT_fit($pda, $in, $out);
@@ -208,7 +207,7 @@ sub array {
 		if (@_ == 1 && (ref($_[0]) eq 'ARRAY' || UNIVERSAL::isa($_[0], 'Math::Matrix'))) {
 			
 			# verify array structure
-			(ref($_[0][0]) eq 'ARRAY' && ! ref($_[0][0][0])) || croak('improper coefficient array structure');
+			(ref($_[0][0]) eq 'ARRAY' && ! ref($_[0][0][0])) or croak('improper coefficient array structure');
 			
 			# set CLUT to new array
 			$self->[2] = bless(Storable::dclone(shift()), 'Math::Matrix');
@@ -309,7 +308,7 @@ sub inverse {
 	$i = $j = -1;
 
 	# build slice arrays while validating input and output arrays
-	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) || croak('wrong number of undefined values');
+	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) or croak('wrong number of undefined values');
 
 	# get init array
 	$init = $hash->{'init'};
@@ -411,7 +410,7 @@ sub jacobian {
 	my ($xflag, $ext, $ubox, $jac, $delta, $out);
 
 	# verify input vector
-	(ref($in) eq 'ARRAY' && @{$in} == @{$self->[1]} && @{$in} == grep {! ref()} @{$in}) || croak('invalid jacobian input');
+	(ref($in) eq 'ARRAY' && @{$in} == @{$self->[1]} && @{$in} == grep {! ref()} @{$in}) or croak('invalid jacobian input');
 
 	# if extrapolation required (any input outside the unit box)
 	if ($xflag = $hash->{'ubox'} && grep {$_ < 0 || $_ > 1} @{$in}) {
@@ -696,13 +695,13 @@ sub _new_from_hash {
 	my ($pda, $coef, $size);
 
 	# get input polynomial degree array (pda) reference
-	$pda = $hash->{'pda'} || croak('missing polynomial degree array');
+	$pda = $hash->{'pda'} or croak('missing polynomial degree array');
 
 	# get output coefficient array reference
-	$coef = $hash->{'coef'} || croak('missing coefficient array');
+	$coef = $hash->{'coef'} or croak('missing coefficient array');
 
 	# verify pda structure
-	(ref($pda) eq 'ARRAY' && ! ref($pda->[0])) || croak('improper polynomial degree array');
+	(ref($pda) eq 'ARRAY' && ! ref($pda->[0])) or croak('improper polynomial degree array');
 
 	# copy pda to object
 	$self->[1] = [@{$pda}];
@@ -719,10 +718,10 @@ sub _new_from_hash {
 	}
 
 	# verify coef is array or Math::Matrix object
-	(ref($coef) eq 'ARRAY' || UNIVERSAL::isa($coef, 'Math::Matrix')) || croak('improper coefficient array type');
+	(ref($coef) eq 'ARRAY' || UNIVERSAL::isa($coef, 'Math::Matrix')) or croak('improper coefficient array type');
 
 	# verify coef structure
-	(ref($coef->[0]) eq 'ARRAY' && ! ref($coef->[0][0]) && @{$coef} == $size) || croak('improper coefficient array structure');
+	(ref($coef->[0]) eq 'ARRAY' && ! ref($coef->[0][0]) && @{$coef} == $size) or croak('improper coefficient array structure');
 
 	# copy coefficient array to object
 	$self->[2] = bless(Storable::dclone($coef), 'Math::Matrix');
@@ -742,14 +741,11 @@ sub _new_from_storable {
 	# local variables
 	my ($hash, @files);
 
-	# resolve file list from path
-	(@files = File::Glob::bsd_glob($path)) || croak('invalid file path');
-
-	# verify file path is unique
-	(@files == 1) || carp('file path not unique');
+	# filter path
+	ICC::Shared::filterPath($path);
 
 	# retrieve hash reference
-	$hash = Storable::retrieve($files[0]);
+	$hash = Storable::retrieve($path);
 
 	# if successful
 	if (defined($hash)) {
