@@ -199,7 +199,7 @@ sub matrix {
 		if (@_ == 1 && ((ref($_[0]) eq 'ARRAY' && @{$_[0]} == grep {ref() eq 'ARRAY'} @{$_[0]}) || UNIVERSAL::isa($_[0], 'Math::Matrix'))) {
 			
 			# verify number of rows
-			($#{$_[0]} < 6) || croak('\'matrix\' array has more than 6 rows');
+			($#{$_[0]} < 6) or croak('\'matrix\' array has more than 6 rows');
 			
 			# make identity matrix (6x4)
 			$self->[1] = bless([
@@ -215,13 +215,13 @@ sub matrix {
 			for my $i (0 .. $#{$_[0]}) {
 				
 				# verify number of columns
-				($#{$_[0]->[$i]} < 4) || croak('\'matrix\' array has more than 4 columns');
+				($#{$_[0]->[$i]} < 4) or croak('\'matrix\' array has more than 4 columns');
 				
 				# for each column
 				for my $j (0 .. $#{$_[0]->[$i]}) {
 					
 					# verify matrix element is a number
-					(Scalar::Util::looks_like_number($_[0]->[$i][$j])) || croak('\'matrix\' element not numeric');
+					(Scalar::Util::looks_like_number($_[0]->[$i][$j])) or croak('\'matrix\' element not numeric');
 					
 					# copy matrix element
 					$self->[1][$i][$j] = $_[0]->[$i][$j];
@@ -262,21 +262,21 @@ sub fit {
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
 
 	# verify ICC::Support::Lapack module is loaded
-	($lapack) || croak('\'fit\' method requires ICC::Support::Lapack module');
+	($lapack) or croak('\'fit\' method requires ICC::Support::Lapack module');
 
 	# resolve offset flag
 	$oflag = 0 if (! defined($oflag));
 
 	# verify input array
-	(ref($in) eq 'ARRAY' && ref($in->[0]) eq 'ARRAY' && ! ref($in->[0][0])) || UNIVERSAL::isa($in, 'Math::Matrix') || croak('fit input not a 2-D array reference');
+	(ref($in) eq 'ARRAY' && ref($in->[0]) eq 'ARRAY' && ! ref($in->[0][0])) || UNIVERSAL::isa($in, 'Math::Matrix') or croak('fit input not a 2-D array reference');
 
 	# verify output array
-	(ref($out) eq 'ARRAY' && ref($out->[0]) eq 'ARRAY' && ! ref($out->[0][0])) || UNIVERSAL::isa($out, 'Math::Matrix') || croak('fit output not a 2-D array reference');
+	(ref($out) eq 'ARRAY' && ref($out->[0]) eq 'ARRAY' && ! ref($out->[0][0])) || UNIVERSAL::isa($out, 'Math::Matrix') or croak('fit output not a 2-D array reference');
 
 	# verify array dimensions
-	($#{$in} == $#{$out}) || croak('input and output arrays have different number of rows');
-	($#{$in->[0]} == 2) || croak('input samples must have 3 elements');
-	($#{$out->[0]} == 2) || croak('output samples must have 3 elements');
+	($#{$in} == $#{$out}) or croak('input and output arrays have different number of rows');
+	($#{$in->[0]} == 2) or croak('input samples must have 3 elements');
+	($#{$out->[0]} == 2) or croak('output samples must have 3 elements');
 
 	# fit the matrix
 	($info, $ab) = ICC::Support::Lapack::matf_fit($in, $out, $oflag);
@@ -390,7 +390,7 @@ sub inverse {
 	$i = $j = -1;
 
 	# build slice arrays while validating input and output arrays
-	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) || croak('wrong number of undefined values');
+	((grep {$i++; defined() && push(@si, $i)} @{$in}) == (grep {$j++; ! defined() && push(@so, $j)} @{$out})) or croak('wrong number of undefined values');
 
 	# for each undefined output value
 	for my $i (@so) {
@@ -637,7 +637,7 @@ sub _trans0 {
 	$hash = pop() if (ref($_[-1]) eq 'HASH');
 
 	# validate number of input channels
-	(@_ == 3) || croak('input samples must have 3 channels');
+	(@_ == 3) or croak('input samples must have 3 channels');
 
 	# augment input sample
 	push(@_, 1);
@@ -670,7 +670,7 @@ sub _trans1 {
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
 
 	# validate number of input channels
-	(@{$in} == 3) || croak('input samples must have 3 channels');
+	(@{$in} == 3) or croak('input samples must have 3 channels');
 
 	# if ICC::Support::Lapack module is loaded
 	if ($lapack) {
@@ -702,7 +702,7 @@ sub _trans2 {
 	state $lapack = defined($INC{'ICC/Support/Lapack.pm'});
 
 	# validate number of input channels
-	(@{$in->[0]} == 3) || croak('input samples must have 3 channels');
+	(@{$in->[0]} == 3) or croak('input samples must have 3 channels');
 
 	# if ICC::Support::Lapack module is loaded
 	if ($lapack) {
@@ -778,19 +778,19 @@ sub _new_from_matf {
 	$value = $matf->matrix;
 
 	# verify number of rows
-	($#{$value} < 6) || croak('\'matf\' matrix has more than 6 rows');
+	($#{$value} < 6) or croak('\'matf\' matrix has more than 6 rows');
 
 	# for each row
 	for my $i (0 .. $#{$value}) {
 		
 		# verify number of columns
-		($#{$value->[$i]} < 3) || croak('\'matf\' matrix has more than 3 columns');
+		($#{$value->[$i]} < 3) or croak('\'matf\' matrix has more than 3 columns');
 		
 		# for each column
 		for my $j (0 .. $#{$value->[$i]}) {
 			
 			# verify matrix element is a number
-			(Scalar::Util::looks_like_number($value->[$i][$j])) || croak('\'matf\' matrix element not numeric');
+			(Scalar::Util::looks_like_number($value->[$i][$j])) or croak('\'matf\' matrix element not numeric');
 			
 			# copy matrix element
 			$self->[1][$i][$j] = $value->[$i][$j];
@@ -803,13 +803,13 @@ sub _new_from_matf {
 	$value = $matf->offset;
 
 	# verify number of elements
-	($#{$value} < 3) || croak('\'matf\' offset has more than 3 elements');
+	($#{$value} < 3) or croak('\'matf\' offset has more than 3 elements');
 
 	# for each element
 	for my $i (0 .. $#{$value}) {
 		
 		# verify array element is a number
-		(Scalar::Util::looks_like_number($value->[$i])) || croak('\'matf\' offset element not numeric');
+		(Scalar::Util::looks_like_number($value->[$i])) or croak('\'matf\' offset element not numeric');
 		
 		# copy offset to object
 		$self->[1][$i][3] = $value->[$i];
@@ -868,19 +868,19 @@ sub _new_from_hash {
 		if ((ref($value) eq 'ARRAY' && @{$value} == grep {ref() eq 'ARRAY'} @{$value}) || UNIVERSAL::isa($value, 'Math::Matrix')) {
 			
 			# verify number of rows
-			($#{$value} < 6) || croak('\'matrix\' array has more than 6 rows');
+			($#{$value} < 6) or croak('\'matrix\' array has more than 6 rows');
 			
 			# for each row
 			for my $i (0 .. $#{$value}) {
 				
 				# verify number of columns
-				($#{$value->[$i]} < 4) || croak('\'matrix\' array has more than 4 columns');
+				($#{$value->[$i]} < 4) or croak('\'matrix\' array has more than 4 columns');
 				
 				# for each column
 				for my $j (0 .. $#{$value->[$i]}) {
 					
 					# verify matrix element is a number
-					(Scalar::Util::looks_like_number($value->[$i][$j])) || croak('\'matrix\' element not numeric');
+					(Scalar::Util::looks_like_number($value->[$i][$j])) or croak('\'matrix\' element not numeric');
 					
 					# copy matrix element
 					$self->[1][$i][$j] = $value->[$i][$j];
@@ -908,13 +908,13 @@ sub _new_from_hash {
 		if (ref($value) eq 'ARRAY' && @{$value} == grep {! ref()} @{$value}) {
 			
 			# verify number of elements
-			($#{$value} < 3) || croak('\'offset\' array has more than 3 elements');
+			($#{$value} < 3) or croak('\'offset\' array has more than 3 elements');
 			
 			# for each element
 			for my $i (0 .. $#{$value}) {
 				
 				# verify array element is a number
-				(Scalar::Util::looks_like_number($value->[$i])) || croak('\'offset\' element not numeric');
+				(Scalar::Util::looks_like_number($value->[$i])) or croak('\'offset\' element not numeric');
 				
 				# copy offset to object
 				$self->[1][$i][3] = $value->[$i];
