@@ -38,19 +38,19 @@ sub new {
 	if (@_ == 2 || @_ == 3) {
 		
 		# verify parameter array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# verify function type
-		($_[0][0] == int($_[0][0]) && defined($Np[$_[0][0]])) || croak('invalid function type');
+		($_[0][0] == int($_[0][0]) && defined($Np[$_[0][0]])) or croak('invalid function type');
 		
 		# verify number of parameters
-		($#{$_[0]} == $Np[$_[0][0]]) || croak('wrong number of parameters');
+		($#{$_[0]} == $Np[$_[0][0]]) or croak('wrong number of parameters');
 		
 		# copy parameter array
 		$self->[1] = [@{shift()}];
 		
 		# verify center array reference
-		(ref($_[0]) eq 'ARRAY') || croak('not an array reference');
+		(ref($_[0]) eq 'ARRAY') or croak('not an array reference');
 		
 		# copy center array
 		$self->[2] = [@{shift()}];
@@ -62,10 +62,10 @@ sub new {
 			(my $info, $self->[3]) = ICC::Support::Lapack::inv(shift());
 			
 			# quit on error
-			($info == 0) || croak("inversion of convariance matrix failed: info= $info");
+			($info == 0) or croak("inversion of convariance matrix failed: info= $info");
 			
 			# verify center and covariance are same size
-			($#{$self->[2]} == $#{$self->[3]}) || croak('center and covariance are different sizes');
+			($#{$self->[2]} == $#{$self->[3]}) or croak('center and covariance are different sizes');
 			
 		}
 		
@@ -377,16 +377,16 @@ sub array {
 		$array = shift();
 		
 		# verify array reference
-		(ref($array) eq 'ARRAY') || croak('not an array reference');
+		(ref($array) eq 'ARRAY') or croak('not an array reference');
 		
 		# get function type
 		$type = $array->[0];
 		
 		# verify function type
-		($type == int($type) && $type >= 0 && defined($Np[$_[0][0]])) || croak('invalid function type');
+		($type == int($type) && $type >= 0 && defined($Np[$_[0][0]])) or croak('invalid function type');
 		
 		# verify number of parameters
-		($#{$array} == $Np[$type]) || croak('wrong number of parameters');
+		($#{$array} == $Np[$type]) or croak('wrong number of parameters');
 		
 		# set array reference
 		$self->[1] = $array;
@@ -416,7 +416,7 @@ sub center {
 		$array = shift();
 		
 		# verify array reference
-		(ref($array) eq 'ARRAY') || croak('not an array reference');
+		(ref($array) eq 'ARRAY') or croak('not an array reference');
 		
 		# set array reference
 		$self->[2] = $array;
@@ -446,7 +446,7 @@ sub matrix {
 		$matrix = shift();
 		
 		# verify matrix reference
-		(ref($matrix) eq 'ARRAY' && ref($matrix->[0]) eq 'ARRAY') || croak('not a matrix reference');
+		(ref($matrix) eq 'ARRAY' && ref($matrix->[0]) eq 'ARRAY') or croak('not a matrix reference');
 		
 		# set matrix reference
 		$self->[3] = $matrix;
